// For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT
package capstone;

public class Arm64_const {

	public static final int ARM64_SFT_INVALID = 0;
	public static final int ARM64_SFT_LSL = 1;
	public static final int ARM64_SFT_MSL = 2;
	public static final int ARM64_SFT_LSR = 3;
	public static final int ARM64_SFT_ASR = 4;
	public static final int ARM64_SFT_ROR = 5;

	public static final int ARM64_EXT_INVALID = 0;
	public static final int ARM64_EXT_UXTB = 1;
	public static final int ARM64_EXT_UXTH = 2;
	public static final int ARM64_EXT_UXTW = 3;
	public static final int ARM64_EXT_UXTX = 4;
	public static final int ARM64_EXT_SXTB = 5;
	public static final int ARM64_EXT_SXTH = 6;
	public static final int ARM64_EXT_SXTW = 7;
	public static final int ARM64_EXT_SXTX = 8;

	public static final int ARM64_CC_INVALID = 0;
	public static final int ARM64_CC_EQ = 1;
	public static final int ARM64_CC_NE = 2;
	public static final int ARM64_CC_HS = 3;
	public static final int ARM64_CC_LO = 4;
	public static final int ARM64_CC_MI = 5;
	public static final int ARM64_CC_PL = 6;
	public static final int ARM64_CC_VS = 7;
	public static final int ARM64_CC_VC = 8;
	public static final int ARM64_CC_HI = 9;
	public static final int ARM64_CC_LS = 10;
	public static final int ARM64_CC_GE = 11;
	public static final int ARM64_CC_LT = 12;
	public static final int ARM64_CC_GT = 13;
	public static final int ARM64_CC_LE = 14;
	public static final int ARM64_CC_AL = 15;
	public static final int ARM64_CC_NV = 16;

	public static final int ARM64_SYSREG_INVALID = 0;
	public static final int ARM64_SYSREG_ACCDATA_EL1 = 0xC685;
	public static final int ARM64_SYSREG_ACTLR_EL1 = 0xC081;
	public static final int ARM64_SYSREG_ACTLR_EL2 = 0xE081;
	public static final int ARM64_SYSREG_ACTLR_EL3 = 0xF081;
	public static final int ARM64_SYSREG_AFSR0_EL1 = 0xC288;
	public static final int ARM64_SYSREG_AFSR0_EL12 = 0xEA88;
	public static final int ARM64_SYSREG_AFSR0_EL2 = 0xE288;
	public static final int ARM64_SYSREG_AFSR0_EL3 = 0xF288;
	public static final int ARM64_SYSREG_AFSR1_EL1 = 0xC289;
	public static final int ARM64_SYSREG_AFSR1_EL12 = 0xEA89;
	public static final int ARM64_SYSREG_AFSR1_EL2 = 0xE289;
	public static final int ARM64_SYSREG_AFSR1_EL3 = 0xF289;
	public static final int ARM64_SYSREG_AIDR_EL1 = 0xC807;
	public static final int ARM64_SYSREG_AMAIR_EL1 = 0xC518;
	public static final int ARM64_SYSREG_AMAIR_EL12 = 0xED18;
	public static final int ARM64_SYSREG_AMAIR_EL2 = 0xE518;
	public static final int ARM64_SYSREG_AMAIR_EL3 = 0xF518;
	public static final int ARM64_SYSREG_AMCFGR_EL0 = 0xDE91;
	public static final int ARM64_SYSREG_AMCGCR_EL0 = 0xDE92;
	public static final int ARM64_SYSREG_AMCNTENCLR0_EL0 = 0xDE94;
	public static final int ARM64_SYSREG_AMCNTENCLR1_EL0 = 0xDE98;
	public static final int ARM64_SYSREG_AMCNTENSET0_EL0 = 0xDE95;
	public static final int ARM64_SYSREG_AMCNTENSET1_EL0 = 0xDE99;
	public static final int ARM64_SYSREG_AMCR_EL0 = 0xDE90;
	public static final int ARM64_SYSREG_AMEVCNTR00_EL0 = 0xDEA0;
	public static final int ARM64_SYSREG_AMEVCNTR01_EL0 = 0xDEA1;
	public static final int ARM64_SYSREG_AMEVCNTR02_EL0 = 0xDEA2;
	public static final int ARM64_SYSREG_AMEVCNTR03_EL0 = 0xDEA3;
	public static final int ARM64_SYSREG_AMEVCNTR10_EL0 = 0xDEE0;
	public static final int ARM64_SYSREG_AMEVCNTR110_EL0 = 0xDEEA;
	public static final int ARM64_SYSREG_AMEVCNTR111_EL0 = 0xDEEB;
	public static final int ARM64_SYSREG_AMEVCNTR112_EL0 = 0xDEEC;
	public static final int ARM64_SYSREG_AMEVCNTR113_EL0 = 0xDEED;
	public static final int ARM64_SYSREG_AMEVCNTR114_EL0 = 0xDEEE;
	public static final int ARM64_SYSREG_AMEVCNTR115_EL0 = 0xDEEF;
	public static final int ARM64_SYSREG_AMEVCNTR11_EL0 = 0xDEE1;
	public static final int ARM64_SYSREG_AMEVCNTR12_EL0 = 0xDEE2;
	public static final int ARM64_SYSREG_AMEVCNTR13_EL0 = 0xDEE3;
	public static final int ARM64_SYSREG_AMEVCNTR14_EL0 = 0xDEE4;
	public static final int ARM64_SYSREG_AMEVCNTR15_EL0 = 0xDEE5;
	public static final int ARM64_SYSREG_AMEVCNTR16_EL0 = 0xDEE6;
	public static final int ARM64_SYSREG_AMEVCNTR17_EL0 = 0xDEE7;
	public static final int ARM64_SYSREG_AMEVCNTR18_EL0 = 0xDEE8;
	public static final int ARM64_SYSREG_AMEVCNTR19_EL0 = 0xDEE9;
	public static final int ARM64_SYSREG_AMEVCNTVOFF00_EL2 = 0xE6C0;
	public static final int ARM64_SYSREG_AMEVCNTVOFF010_EL2 = 0xE6CA;
	public static final int ARM64_SYSREG_AMEVCNTVOFF011_EL2 = 0xE6CB;
	public static final int ARM64_SYSREG_AMEVCNTVOFF012_EL2 = 0xE6CC;
	public static final int ARM64_SYSREG_AMEVCNTVOFF013_EL2 = 0xE6CD;
	public static final int ARM64_SYSREG_AMEVCNTVOFF014_EL2 = 0xE6CE;
	public static final int ARM64_SYSREG_AMEVCNTVOFF015_EL2 = 0xE6CF;
	public static final int ARM64_SYSREG_AMEVCNTVOFF01_EL2 = 0xE6C1;
	public static final int ARM64_SYSREG_AMEVCNTVOFF02_EL2 = 0xE6C2;
	public static final int ARM64_SYSREG_AMEVCNTVOFF03_EL2 = 0xE6C3;
	public static final int ARM64_SYSREG_AMEVCNTVOFF04_EL2 = 0xE6C4;
	public static final int ARM64_SYSREG_AMEVCNTVOFF05_EL2 = 0xE6C5;
	public static final int ARM64_SYSREG_AMEVCNTVOFF06_EL2 = 0xE6C6;
	public static final int ARM64_SYSREG_AMEVCNTVOFF07_EL2 = 0xE6C7;
	public static final int ARM64_SYSREG_AMEVCNTVOFF08_EL2 = 0xE6C8;
	public static final int ARM64_SYSREG_AMEVCNTVOFF09_EL2 = 0xE6C9;
	public static final int ARM64_SYSREG_AMEVCNTVOFF10_EL2 = 0xE6D0;
	public static final int ARM64_SYSREG_AMEVCNTVOFF110_EL2 = 0xE6DA;
	public static final int ARM64_SYSREG_AMEVCNTVOFF111_EL2 = 0xE6DB;
	public static final int ARM64_SYSREG_AMEVCNTVOFF112_EL2 = 0xE6DC;
	public static final int ARM64_SYSREG_AMEVCNTVOFF113_EL2 = 0xE6DD;
	public static final int ARM64_SYSREG_AMEVCNTVOFF114_EL2 = 0xE6DE;
	public static final int ARM64_SYSREG_AMEVCNTVOFF115_EL2 = 0xE6DF;
	public static final int ARM64_SYSREG_AMEVCNTVOFF11_EL2 = 0xE6D1;
	public static final int ARM64_SYSREG_AMEVCNTVOFF12_EL2 = 0xE6D2;
	public static final int ARM64_SYSREG_AMEVCNTVOFF13_EL2 = 0xE6D3;
	public static final int ARM64_SYSREG_AMEVCNTVOFF14_EL2 = 0xE6D4;
	public static final int ARM64_SYSREG_AMEVCNTVOFF15_EL2 = 0xE6D5;
	public static final int ARM64_SYSREG_AMEVCNTVOFF16_EL2 = 0xE6D6;
	public static final int ARM64_SYSREG_AMEVCNTVOFF17_EL2 = 0xE6D7;
	public static final int ARM64_SYSREG_AMEVCNTVOFF18_EL2 = 0xE6D8;
	public static final int ARM64_SYSREG_AMEVCNTVOFF19_EL2 = 0xE6D9;
	public static final int ARM64_SYSREG_AMEVTYPER00_EL0 = 0xDEB0;
	public static final int ARM64_SYSREG_AMEVTYPER01_EL0 = 0xDEB1;
	public static final int ARM64_SYSREG_AMEVTYPER02_EL0 = 0xDEB2;
	public static final int ARM64_SYSREG_AMEVTYPER03_EL0 = 0xDEB3;
	public static final int ARM64_SYSREG_AMEVTYPER10_EL0 = 0xDEF0;
	public static final int ARM64_SYSREG_AMEVTYPER110_EL0 = 0xDEFA;
	public static final int ARM64_SYSREG_AMEVTYPER111_EL0 = 0xDEFB;
	public static final int ARM64_SYSREG_AMEVTYPER112_EL0 = 0xDEFC;
	public static final int ARM64_SYSREG_AMEVTYPER113_EL0 = 0xDEFD;
	public static final int ARM64_SYSREG_AMEVTYPER114_EL0 = 0xDEFE;
	public static final int ARM64_SYSREG_AMEVTYPER115_EL0 = 0xDEFF;
	public static final int ARM64_SYSREG_AMEVTYPER11_EL0 = 0xDEF1;
	public static final int ARM64_SYSREG_AMEVTYPER12_EL0 = 0xDEF2;
	public static final int ARM64_SYSREG_AMEVTYPER13_EL0 = 0xDEF3;
	public static final int ARM64_SYSREG_AMEVTYPER14_EL0 = 0xDEF4;
	public static final int ARM64_SYSREG_AMEVTYPER15_EL0 = 0xDEF5;
	public static final int ARM64_SYSREG_AMEVTYPER16_EL0 = 0xDEF6;
	public static final int ARM64_SYSREG_AMEVTYPER17_EL0 = 0xDEF7;
	public static final int ARM64_SYSREG_AMEVTYPER18_EL0 = 0xDEF8;
	public static final int ARM64_SYSREG_AMEVTYPER19_EL0 = 0xDEF9;
	public static final int ARM64_SYSREG_AMUSERENR_EL0 = 0xDE93;
	public static final int ARM64_SYSREG_APDAKEYHI_EL1 = 0xC111;
	public static final int ARM64_SYSREG_APDAKEYLO_EL1 = 0xC110;
	public static final int ARM64_SYSREG_APDBKEYHI_EL1 = 0xC113;
	public static final int ARM64_SYSREG_APDBKEYLO_EL1 = 0xC112;
	public static final int ARM64_SYSREG_APGAKEYHI_EL1 = 0xC119;
	public static final int ARM64_SYSREG_APGAKEYLO_EL1 = 0xC118;
	public static final int ARM64_SYSREG_APIAKEYHI_EL1 = 0xC109;
	public static final int ARM64_SYSREG_APIAKEYLO_EL1 = 0xC108;
	public static final int ARM64_SYSREG_APIBKEYHI_EL1 = 0xC10B;
	public static final int ARM64_SYSREG_APIBKEYLO_EL1 = 0xC10A;
	public static final int ARM64_SYSREG_BRBCR_EL1 = 0x8C80;
	public static final int ARM64_SYSREG_BRBCR_EL12 = 0xAC80;
	public static final int ARM64_SYSREG_BRBCR_EL2 = 0xA480;
	public static final int ARM64_SYSREG_BRBFCR_EL1 = 0x8C81;
	public static final int ARM64_SYSREG_BRBIDR0_EL1 = 0x8C90;
	public static final int ARM64_SYSREG_BRBINF0_EL1 = 0x8C00;
	public static final int ARM64_SYSREG_BRBINF10_EL1 = 0x8C50;
	public static final int ARM64_SYSREG_BRBINF11_EL1 = 0x8C58;
	public static final int ARM64_SYSREG_BRBINF12_EL1 = 0x8C60;
	public static final int ARM64_SYSREG_BRBINF13_EL1 = 0x8C68;
	public static final int ARM64_SYSREG_BRBINF14_EL1 = 0x8C70;
	public static final int ARM64_SYSREG_BRBINF15_EL1 = 0x8C78;
	public static final int ARM64_SYSREG_BRBINF16_EL1 = 0x8C04;
	public static final int ARM64_SYSREG_BRBINF17_EL1 = 0x8C0C;
	public static final int ARM64_SYSREG_BRBINF18_EL1 = 0x8C14;
	public static final int ARM64_SYSREG_BRBINF19_EL1 = 0x8C1C;
	public static final int ARM64_SYSREG_BRBINF1_EL1 = 0x8C08;
	public static final int ARM64_SYSREG_BRBINF20_EL1 = 0x8C24;
	public static final int ARM64_SYSREG_BRBINF21_EL1 = 0x8C2C;
	public static final int ARM64_SYSREG_BRBINF22_EL1 = 0x8C34;
	public static final int ARM64_SYSREG_BRBINF23_EL1 = 0x8C3C;
	public static final int ARM64_SYSREG_BRBINF24_EL1 = 0x8C44;
	public static final int ARM64_SYSREG_BRBINF25_EL1 = 0x8C4C;
	public static final int ARM64_SYSREG_BRBINF26_EL1 = 0x8C54;
	public static final int ARM64_SYSREG_BRBINF27_EL1 = 0x8C5C;
	public static final int ARM64_SYSREG_BRBINF28_EL1 = 0x8C64;
	public static final int ARM64_SYSREG_BRBINF29_EL1 = 0x8C6C;
	public static final int ARM64_SYSREG_BRBINF2_EL1 = 0x8C10;
	public static final int ARM64_SYSREG_BRBINF30_EL1 = 0x8C74;
	public static final int ARM64_SYSREG_BRBINF31_EL1 = 0x8C7C;
	public static final int ARM64_SYSREG_BRBINF3_EL1 = 0x8C18;
	public static final int ARM64_SYSREG_BRBINF4_EL1 = 0x8C20;
	public static final int ARM64_SYSREG_BRBINF5_EL1 = 0x8C28;
	public static final int ARM64_SYSREG_BRBINF6_EL1 = 0x8C30;
	public static final int ARM64_SYSREG_BRBINF7_EL1 = 0x8C38;
	public static final int ARM64_SYSREG_BRBINF8_EL1 = 0x8C40;
	public static final int ARM64_SYSREG_BRBINF9_EL1 = 0x8C48;
	public static final int ARM64_SYSREG_BRBINFINJ_EL1 = 0x8C88;
	public static final int ARM64_SYSREG_BRBSRC0_EL1 = 0x8C01;
	public static final int ARM64_SYSREG_BRBSRC10_EL1 = 0x8C51;
	public static final int ARM64_SYSREG_BRBSRC11_EL1 = 0x8C59;
	public static final int ARM64_SYSREG_BRBSRC12_EL1 = 0x8C61;
	public static final int ARM64_SYSREG_BRBSRC13_EL1 = 0x8C69;
	public static final int ARM64_SYSREG_BRBSRC14_EL1 = 0x8C71;
	public static final int ARM64_SYSREG_BRBSRC15_EL1 = 0x8C79;
	public static final int ARM64_SYSREG_BRBSRC16_EL1 = 0x8C05;
	public static final int ARM64_SYSREG_BRBSRC17_EL1 = 0x8C0D;
	public static final int ARM64_SYSREG_BRBSRC18_EL1 = 0x8C15;
	public static final int ARM64_SYSREG_BRBSRC19_EL1 = 0x8C1D;
	public static final int ARM64_SYSREG_BRBSRC1_EL1 = 0x8C09;
	public static final int ARM64_SYSREG_BRBSRC20_EL1 = 0x8C25;
	public static final int ARM64_SYSREG_BRBSRC21_EL1 = 0x8C2D;
	public static final int ARM64_SYSREG_BRBSRC22_EL1 = 0x8C35;
	public static final int ARM64_SYSREG_BRBSRC23_EL1 = 0x8C3D;
	public static final int ARM64_SYSREG_BRBSRC24_EL1 = 0x8C45;
	public static final int ARM64_SYSREG_BRBSRC25_EL1 = 0x8C4D;
	public static final int ARM64_SYSREG_BRBSRC26_EL1 = 0x8C55;
	public static final int ARM64_SYSREG_BRBSRC27_EL1 = 0x8C5D;
	public static final int ARM64_SYSREG_BRBSRC28_EL1 = 0x8C65;
	public static final int ARM64_SYSREG_BRBSRC29_EL1 = 0x8C6D;
	public static final int ARM64_SYSREG_BRBSRC2_EL1 = 0x8C11;
	public static final int ARM64_SYSREG_BRBSRC30_EL1 = 0x8C75;
	public static final int ARM64_SYSREG_BRBSRC31_EL1 = 0x8C7D;
	public static final int ARM64_SYSREG_BRBSRC3_EL1 = 0x8C19;
	public static final int ARM64_SYSREG_BRBSRC4_EL1 = 0x8C21;
	public static final int ARM64_SYSREG_BRBSRC5_EL1 = 0x8C29;
	public static final int ARM64_SYSREG_BRBSRC6_EL1 = 0x8C31;
	public static final int ARM64_SYSREG_BRBSRC7_EL1 = 0x8C39;
	public static final int ARM64_SYSREG_BRBSRC8_EL1 = 0x8C41;
	public static final int ARM64_SYSREG_BRBSRC9_EL1 = 0x8C49;
	public static final int ARM64_SYSREG_BRBSRCINJ_EL1 = 0x8C89;
	public static final int ARM64_SYSREG_BRBTGT0_EL1 = 0x8C02;
	public static final int ARM64_SYSREG_BRBTGT10_EL1 = 0x8C52;
	public static final int ARM64_SYSREG_BRBTGT11_EL1 = 0x8C5A;
	public static final int ARM64_SYSREG_BRBTGT12_EL1 = 0x8C62;
	public static final int ARM64_SYSREG_BRBTGT13_EL1 = 0x8C6A;
	public static final int ARM64_SYSREG_BRBTGT14_EL1 = 0x8C72;
	public static final int ARM64_SYSREG_BRBTGT15_EL1 = 0x8C7A;
	public static final int ARM64_SYSREG_BRBTGT16_EL1 = 0x8C06;
	public static final int ARM64_SYSREG_BRBTGT17_EL1 = 0x8C0E;
	public static final int ARM64_SYSREG_BRBTGT18_EL1 = 0x8C16;
	public static final int ARM64_SYSREG_BRBTGT19_EL1 = 0x8C1E;
	public static final int ARM64_SYSREG_BRBTGT1_EL1 = 0x8C0A;
	public static final int ARM64_SYSREG_BRBTGT20_EL1 = 0x8C26;
	public static final int ARM64_SYSREG_BRBTGT21_EL1 = 0x8C2E;
	public static final int ARM64_SYSREG_BRBTGT22_EL1 = 0x8C36;
	public static final int ARM64_SYSREG_BRBTGT23_EL1 = 0x8C3E;
	public static final int ARM64_SYSREG_BRBTGT24_EL1 = 0x8C46;
	public static final int ARM64_SYSREG_BRBTGT25_EL1 = 0x8C4E;
	public static final int ARM64_SYSREG_BRBTGT26_EL1 = 0x8C56;
	public static final int ARM64_SYSREG_BRBTGT27_EL1 = 0x8C5E;
	public static final int ARM64_SYSREG_BRBTGT28_EL1 = 0x8C66;
	public static final int ARM64_SYSREG_BRBTGT29_EL1 = 0x8C6E;
	public static final int ARM64_SYSREG_BRBTGT2_EL1 = 0x8C12;
	public static final int ARM64_SYSREG_BRBTGT30_EL1 = 0x8C76;
	public static final int ARM64_SYSREG_BRBTGT31_EL1 = 0x8C7E;
	public static final int ARM64_SYSREG_BRBTGT3_EL1 = 0x8C1A;
	public static final int ARM64_SYSREG_BRBTGT4_EL1 = 0x8C22;
	public static final int ARM64_SYSREG_BRBTGT5_EL1 = 0x8C2A;
	public static final int ARM64_SYSREG_BRBTGT6_EL1 = 0x8C32;
	public static final int ARM64_SYSREG_BRBTGT7_EL1 = 0x8C3A;
	public static final int ARM64_SYSREG_BRBTGT8_EL1 = 0x8C42;
	public static final int ARM64_SYSREG_BRBTGT9_EL1 = 0x8C4A;
	public static final int ARM64_SYSREG_BRBTGTINJ_EL1 = 0x8C8A;
	public static final int ARM64_SYSREG_BRBTS_EL1 = 0x8C82;
	public static final int ARM64_SYSREG_CCSIDR2_EL1 = 0xC802;
	public static final int ARM64_SYSREG_CCSIDR_EL1 = 0xC800;
	public static final int ARM64_SYSREG_CLIDR_EL1 = 0xC801;
	public static final int ARM64_SYSREG_CNTFRQ_EL0 = 0xDF00;
	public static final int ARM64_SYSREG_CNTHCTL_EL2 = 0xE708;
	public static final int ARM64_SYSREG_CNTHPS_CTL_EL2 = 0xE729;
	public static final int ARM64_SYSREG_CNTHPS_CVAL_EL2 = 0xE72A;
	public static final int ARM64_SYSREG_CNTHPS_TVAL_EL2 = 0xE728;
	public static final int ARM64_SYSREG_CNTHP_CTL_EL2 = 0xE711;
	public static final int ARM64_SYSREG_CNTHP_CVAL_EL2 = 0xE712;
	public static final int ARM64_SYSREG_CNTHP_TVAL_EL2 = 0xE710;
	public static final int ARM64_SYSREG_CNTHVS_CTL_EL2 = 0xE721;
	public static final int ARM64_SYSREG_CNTHVS_CVAL_EL2 = 0xE722;
	public static final int ARM64_SYSREG_CNTHVS_TVAL_EL2 = 0xE720;
	public static final int ARM64_SYSREG_CNTHV_CTL_EL2 = 0xE719;
	public static final int ARM64_SYSREG_CNTHV_CVAL_EL2 = 0xE71A;
	public static final int ARM64_SYSREG_CNTHV_TVAL_EL2 = 0xE718;
	public static final int ARM64_SYSREG_CNTISCALE_EL2 = 0xE705;
	public static final int ARM64_SYSREG_CNTKCTL_EL1 = 0xC708;
	public static final int ARM64_SYSREG_CNTKCTL_EL12 = 0xEF08;
	public static final int ARM64_SYSREG_CNTPCTSS_EL0 = 0xDF05;
	public static final int ARM64_SYSREG_CNTPCT_EL0 = 0xDF01;
	public static final int ARM64_SYSREG_CNTPOFF_EL2 = 0xE706;
	public static final int ARM64_SYSREG_CNTPS_CTL_EL1 = 0xFF11;
	public static final int ARM64_SYSREG_CNTPS_CVAL_EL1 = 0xFF12;
	public static final int ARM64_SYSREG_CNTPS_TVAL_EL1 = 0xFF10;
	public static final int ARM64_SYSREG_CNTP_CTL_EL0 = 0xDF11;
	public static final int ARM64_SYSREG_CNTP_CTL_EL02 = 0xEF11;
	public static final int ARM64_SYSREG_CNTP_CVAL_EL0 = 0xDF12;
	public static final int ARM64_SYSREG_CNTP_CVAL_EL02 = 0xEF12;
	public static final int ARM64_SYSREG_CNTP_TVAL_EL0 = 0xDF10;
	public static final int ARM64_SYSREG_CNTP_TVAL_EL02 = 0xEF10;
	public static final int ARM64_SYSREG_CNTSCALE_EL2 = 0xE704;
	public static final int ARM64_SYSREG_CNTVCTSS_EL0 = 0xDF06;
	public static final int ARM64_SYSREG_CNTVCT_EL0 = 0xDF02;
	public static final int ARM64_SYSREG_CNTVFRQ_EL2 = 0xE707;
	public static final int ARM64_SYSREG_CNTVOFF_EL2 = 0xE703;
	public static final int ARM64_SYSREG_CNTV_CTL_EL0 = 0xDF19;
	public static final int ARM64_SYSREG_CNTV_CTL_EL02 = 0xEF19;
	public static final int ARM64_SYSREG_CNTV_CVAL_EL0 = 0xDF1A;
	public static final int ARM64_SYSREG_CNTV_CVAL_EL02 = 0xEF1A;
	public static final int ARM64_SYSREG_CNTV_TVAL_EL0 = 0xDF18;
	public static final int ARM64_SYSREG_CNTV_TVAL_EL02 = 0xEF18;
	public static final int ARM64_SYSREG_CONTEXTIDR_EL1 = 0xC681;
	public static final int ARM64_SYSREG_CONTEXTIDR_EL12 = 0xEE81;
	public static final int ARM64_SYSREG_CONTEXTIDR_EL2 = 0xE681;
	public static final int ARM64_SYSREG_CPACR_EL1 = 0xC082;
	public static final int ARM64_SYSREG_CPACR_EL12 = 0xE882;
	public static final int ARM64_SYSREG_CPM_IOACC_CTL_EL3 = 0xFF90;
	public static final int ARM64_SYSREG_CPTR_EL2 = 0xE08A;
	public static final int ARM64_SYSREG_CPTR_EL3 = 0xF08A;
	public static final int ARM64_SYSREG_CSSELR_EL1 = 0xD000;
	public static final int ARM64_SYSREG_CTR_EL0 = 0xD801;
	public static final int ARM64_SYSREG_CURRENTEL = 0xC212;
	public static final int ARM64_SYSREG_DACR32_EL2 = 0xE180;
	public static final int ARM64_SYSREG_DAIF = 0xDA11;
	public static final int ARM64_SYSREG_DBGAUTHSTATUS_EL1 = 0x83F6;
	public static final int ARM64_SYSREG_DBGBCR0_EL1 = 0x8005;
	public static final int ARM64_SYSREG_DBGBCR10_EL1 = 0x8055;
	public static final int ARM64_SYSREG_DBGBCR11_EL1 = 0x805D;
	public static final int ARM64_SYSREG_DBGBCR12_EL1 = 0x8065;
	public static final int ARM64_SYSREG_DBGBCR13_EL1 = 0x806D;
	public static final int ARM64_SYSREG_DBGBCR14_EL1 = 0x8075;
	public static final int ARM64_SYSREG_DBGBCR15_EL1 = 0x807D;
	public static final int ARM64_SYSREG_DBGBCR1_EL1 = 0x800D;
	public static final int ARM64_SYSREG_DBGBCR2_EL1 = 0x8015;
	public static final int ARM64_SYSREG_DBGBCR3_EL1 = 0x801D;
	public static final int ARM64_SYSREG_DBGBCR4_EL1 = 0x8025;
	public static final int ARM64_SYSREG_DBGBCR5_EL1 = 0x802D;
	public static final int ARM64_SYSREG_DBGBCR6_EL1 = 0x8035;
	public static final int ARM64_SYSREG_DBGBCR7_EL1 = 0x803D;
	public static final int ARM64_SYSREG_DBGBCR8_EL1 = 0x8045;
	public static final int ARM64_SYSREG_DBGBCR9_EL1 = 0x804D;
	public static final int ARM64_SYSREG_DBGBVR0_EL1 = 0x8004;
	public static final int ARM64_SYSREG_DBGBVR10_EL1 = 0x8054;
	public static final int ARM64_SYSREG_DBGBVR11_EL1 = 0x805C;
	public static final int ARM64_SYSREG_DBGBVR12_EL1 = 0x8064;
	public static final int ARM64_SYSREG_DBGBVR13_EL1 = 0x806C;
	public static final int ARM64_SYSREG_DBGBVR14_EL1 = 0x8074;
	public static final int ARM64_SYSREG_DBGBVR15_EL1 = 0x807C;
	public static final int ARM64_SYSREG_DBGBVR1_EL1 = 0x800C;
	public static final int ARM64_SYSREG_DBGBVR2_EL1 = 0x8014;
	public static final int ARM64_SYSREG_DBGBVR3_EL1 = 0x801C;
	public static final int ARM64_SYSREG_DBGBVR4_EL1 = 0x8024;
	public static final int ARM64_SYSREG_DBGBVR5_EL1 = 0x802C;
	public static final int ARM64_SYSREG_DBGBVR6_EL1 = 0x8034;
	public static final int ARM64_SYSREG_DBGBVR7_EL1 = 0x803C;
	public static final int ARM64_SYSREG_DBGBVR8_EL1 = 0x8044;
	public static final int ARM64_SYSREG_DBGBVR9_EL1 = 0x804C;
	public static final int ARM64_SYSREG_DBGCLAIMCLR_EL1 = 0x83CE;
	public static final int ARM64_SYSREG_DBGCLAIMSET_EL1 = 0x83C6;
	public static final int ARM64_SYSREG_DBGDTRRX_EL0 = 0x9828;
	public static final int ARM64_SYSREG_DBGDTRTX_EL0 = 0x9828;
	public static final int ARM64_SYSREG_DBGDTR_EL0 = 0x9820;
	public static final int ARM64_SYSREG_DBGPRCR_EL1 = 0x80A4;
	public static final int ARM64_SYSREG_DBGVCR32_EL2 = 0xA038;
	public static final int ARM64_SYSREG_DBGWCR0_EL1 = 0x8007;
	public static final int ARM64_SYSREG_DBGWCR10_EL1 = 0x8057;
	public static final int ARM64_SYSREG_DBGWCR11_EL1 = 0x805F;
	public static final int ARM64_SYSREG_DBGWCR12_EL1 = 0x8067;
	public static final int ARM64_SYSREG_DBGWCR13_EL1 = 0x806F;
	public static final int ARM64_SYSREG_DBGWCR14_EL1 = 0x8077;
	public static final int ARM64_SYSREG_DBGWCR15_EL1 = 0x807F;
	public static final int ARM64_SYSREG_DBGWCR1_EL1 = 0x800F;
	public static final int ARM64_SYSREG_DBGWCR2_EL1 = 0x8017;
	public static final int ARM64_SYSREG_DBGWCR3_EL1 = 0x801F;
	public static final int ARM64_SYSREG_DBGWCR4_EL1 = 0x8027;
	public static final int ARM64_SYSREG_DBGWCR5_EL1 = 0x802F;
	public static final int ARM64_SYSREG_DBGWCR6_EL1 = 0x8037;
	public static final int ARM64_SYSREG_DBGWCR7_EL1 = 0x803F;
	public static final int ARM64_SYSREG_DBGWCR8_EL1 = 0x8047;
	public static final int ARM64_SYSREG_DBGWCR9_EL1 = 0x804F;
	public static final int ARM64_SYSREG_DBGWVR0_EL1 = 0x8006;
	public static final int ARM64_SYSREG_DBGWVR10_EL1 = 0x8056;
	public static final int ARM64_SYSREG_DBGWVR11_EL1 = 0x805E;
	public static final int ARM64_SYSREG_DBGWVR12_EL1 = 0x8066;
	public static final int ARM64_SYSREG_DBGWVR13_EL1 = 0x806E;
	public static final int ARM64_SYSREG_DBGWVR14_EL1 = 0x8076;
	public static final int ARM64_SYSREG_DBGWVR15_EL1 = 0x807E;
	public static final int ARM64_SYSREG_DBGWVR1_EL1 = 0x800E;
	public static final int ARM64_SYSREG_DBGWVR2_EL1 = 0x8016;
	public static final int ARM64_SYSREG_DBGWVR3_EL1 = 0x801E;
	public static final int ARM64_SYSREG_DBGWVR4_EL1 = 0x8026;
	public static final int ARM64_SYSREG_DBGWVR5_EL1 = 0x802E;
	public static final int ARM64_SYSREG_DBGWVR6_EL1 = 0x8036;
	public static final int ARM64_SYSREG_DBGWVR7_EL1 = 0x803E;
	public static final int ARM64_SYSREG_DBGWVR8_EL1 = 0x8046;
	public static final int ARM64_SYSREG_DBGWVR9_EL1 = 0x804E;
	public static final int ARM64_SYSREG_DCZID_EL0 = 0xD807;
	public static final int ARM64_SYSREG_DISR_EL1 = 0xC609;
	public static final int ARM64_SYSREG_DIT = 0xDA15;
	public static final int ARM64_SYSREG_DLR_EL0 = 0xDA29;
	public static final int ARM64_SYSREG_DSPSR_EL0 = 0xDA28;
	public static final int ARM64_SYSREG_ELR_EL1 = 0xC201;
	public static final int ARM64_SYSREG_ELR_EL12 = 0xEA01;
	public static final int ARM64_SYSREG_ELR_EL2 = 0xE201;
	public static final int ARM64_SYSREG_ELR_EL3 = 0xF201;
	public static final int ARM64_SYSREG_ERRIDR_EL1 = 0xC298;
	public static final int ARM64_SYSREG_ERRSELR_EL1 = 0xC299;
	public static final int ARM64_SYSREG_ERXADDR_EL1 = 0xC2A3;
	public static final int ARM64_SYSREG_ERXCTLR_EL1 = 0xC2A1;
	public static final int ARM64_SYSREG_ERXFR_EL1 = 0xC2A0;
	public static final int ARM64_SYSREG_ERXMISC0_EL1 = 0xC2A8;
	public static final int ARM64_SYSREG_ERXMISC1_EL1 = 0xC2A9;
	public static final int ARM64_SYSREG_ERXMISC2_EL1 = 0xC2AA;
	public static final int ARM64_SYSREG_ERXMISC3_EL1 = 0xC2AB;
	public static final int ARM64_SYSREG_ERXPFGCDN_EL1 = 0xC2A6;
	public static final int ARM64_SYSREG_ERXPFGCTL_EL1 = 0xC2A5;
	public static final int ARM64_SYSREG_ERXPFGF_EL1 = 0xC2A4;
	public static final int ARM64_SYSREG_ERXSTATUS_EL1 = 0xC2A2;
	public static final int ARM64_SYSREG_ESR_EL1 = 0xC290;
	public static final int ARM64_SYSREG_ESR_EL12 = 0xEA90;
	public static final int ARM64_SYSREG_ESR_EL2 = 0xE290;
	public static final int ARM64_SYSREG_ESR_EL3 = 0xF290;
	public static final int ARM64_SYSREG_FAR_EL1 = 0xC300;
	public static final int ARM64_SYSREG_FAR_EL12 = 0xEB00;
	public static final int ARM64_SYSREG_FAR_EL2 = 0xE300;
	public static final int ARM64_SYSREG_FAR_EL3 = 0xF300;
	public static final int ARM64_SYSREG_FPCR = 0xDA20;
	public static final int ARM64_SYSREG_FPEXC32_EL2 = 0xE298;
	public static final int ARM64_SYSREG_FPSR = 0xDA21;
	public static final int ARM64_SYSREG_GCR_EL1 = 0xC086;
	public static final int ARM64_SYSREG_GMID_EL1 = 0xC804;
	public static final int ARM64_SYSREG_GPCCR_EL3 = 0xF10E;
	public static final int ARM64_SYSREG_GPTBR_EL3 = 0xF10C;
	public static final int ARM64_SYSREG_HACR_EL2 = 0xE08F;
	public static final int ARM64_SYSREG_HCRX_EL2 = 0xE092;
	public static final int ARM64_SYSREG_HCR_EL2 = 0xE088;
	public static final int ARM64_SYSREG_HDFGRTR_EL2 = 0xE18C;
	public static final int ARM64_SYSREG_HDFGWTR_EL2 = 0xE18D;
	public static final int ARM64_SYSREG_HFGITR_EL2 = 0xE08E;
	public static final int ARM64_SYSREG_HFGRTR_EL2 = 0xE08C;
	public static final int ARM64_SYSREG_HFGWTR_EL2 = 0xE08D;
	public static final int ARM64_SYSREG_HPFAR_EL2 = 0xE304;
	public static final int ARM64_SYSREG_HSTR_EL2 = 0xE08B;
	public static final int ARM64_SYSREG_ICC_AP0R0_EL1 = 0xC644;
	public static final int ARM64_SYSREG_ICC_AP0R1_EL1 = 0xC645;
	public static final int ARM64_SYSREG_ICC_AP0R2_EL1 = 0xC646;
	public static final int ARM64_SYSREG_ICC_AP0R3_EL1 = 0xC647;
	public static final int ARM64_SYSREG_ICC_AP1R0_EL1 = 0xC648;
	public static final int ARM64_SYSREG_ICC_AP1R1_EL1 = 0xC649;
	public static final int ARM64_SYSREG_ICC_AP1R2_EL1 = 0xC64A;
	public static final int ARM64_SYSREG_ICC_AP1R3_EL1 = 0xC64B;
	public static final int ARM64_SYSREG_ICC_ASGI1R_EL1 = 0xC65E;
	public static final int ARM64_SYSREG_ICC_BPR0_EL1 = 0xC643;
	public static final int ARM64_SYSREG_ICC_BPR1_EL1 = 0xC663;
	public static final int ARM64_SYSREG_ICC_CTLR_EL1 = 0xC664;
	public static final int ARM64_SYSREG_ICC_CTLR_EL3 = 0xF664;
	public static final int ARM64_SYSREG_ICC_DIR_EL1 = 0xC659;
	public static final int ARM64_SYSREG_ICC_EOIR0_EL1 = 0xC641;
	public static final int ARM64_SYSREG_ICC_EOIR1_EL1 = 0xC661;
	public static final int ARM64_SYSREG_ICC_HPPIR0_EL1 = 0xC642;
	public static final int ARM64_SYSREG_ICC_HPPIR1_EL1 = 0xC662;
	public static final int ARM64_SYSREG_ICC_IAR0_EL1 = 0xC640;
	public static final int ARM64_SYSREG_ICC_IAR1_EL1 = 0xC660;
	public static final int ARM64_SYSREG_ICC_IGRPEN0_EL1 = 0xC666;
	public static final int ARM64_SYSREG_ICC_IGRPEN1_EL1 = 0xC667;
	public static final int ARM64_SYSREG_ICC_IGRPEN1_EL3 = 0xF667;
	public static final int ARM64_SYSREG_ICC_PMR_EL1 = 0xC230;
	public static final int ARM64_SYSREG_ICC_RPR_EL1 = 0xC65B;
	public static final int ARM64_SYSREG_ICC_SGI0R_EL1 = 0xC65F;
	public static final int ARM64_SYSREG_ICC_SGI1R_EL1 = 0xC65D;
	public static final int ARM64_SYSREG_ICC_SRE_EL1 = 0xC665;
	public static final int ARM64_SYSREG_ICC_SRE_EL2 = 0xE64D;
	public static final int ARM64_SYSREG_ICC_SRE_EL3 = 0xF665;
	public static final int ARM64_SYSREG_ICH_AP0R0_EL2 = 0xE640;
	public static final int ARM64_SYSREG_ICH_AP0R1_EL2 = 0xE641;
	public static final int ARM64_SYSREG_ICH_AP0R2_EL2 = 0xE642;
	public static final int ARM64_SYSREG_ICH_AP0R3_EL2 = 0xE643;
	public static final int ARM64_SYSREG_ICH_AP1R0_EL2 = 0xE648;
	public static final int ARM64_SYSREG_ICH_AP1R1_EL2 = 0xE649;
	public static final int ARM64_SYSREG_ICH_AP1R2_EL2 = 0xE64A;
	public static final int ARM64_SYSREG_ICH_AP1R3_EL2 = 0xE64B;
	public static final int ARM64_SYSREG_ICH_EISR_EL2 = 0xE65B;
	public static final int ARM64_SYSREG_ICH_ELRSR_EL2 = 0xE65D;
	public static final int ARM64_SYSREG_ICH_HCR_EL2 = 0xE658;
	public static final int ARM64_SYSREG_ICH_LR0_EL2 = 0xE660;
	public static final int ARM64_SYSREG_ICH_LR10_EL2 = 0xE66A;
	public static final int ARM64_SYSREG_ICH_LR11_EL2 = 0xE66B;
	public static final int ARM64_SYSREG_ICH_LR12_EL2 = 0xE66C;
	public static final int ARM64_SYSREG_ICH_LR13_EL2 = 0xE66D;
	public static final int ARM64_SYSREG_ICH_LR14_EL2 = 0xE66E;
	public static final int ARM64_SYSREG_ICH_LR15_EL2 = 0xE66F;
	public static final int ARM64_SYSREG_ICH_LR1_EL2 = 0xE661;
	public static final int ARM64_SYSREG_ICH_LR2_EL2 = 0xE662;
	public static final int ARM64_SYSREG_ICH_LR3_EL2 = 0xE663;
	public static final int ARM64_SYSREG_ICH_LR4_EL2 = 0xE664;
	public static final int ARM64_SYSREG_ICH_LR5_EL2 = 0xE665;
	public static final int ARM64_SYSREG_ICH_LR6_EL2 = 0xE666;
	public static final int ARM64_SYSREG_ICH_LR7_EL2 = 0xE667;
	public static final int ARM64_SYSREG_ICH_LR8_EL2 = 0xE668;
	public static final int ARM64_SYSREG_ICH_LR9_EL2 = 0xE669;
	public static final int ARM64_SYSREG_ICH_MISR_EL2 = 0xE65A;
	public static final int ARM64_SYSREG_ICH_VMCR_EL2 = 0xE65F;
	public static final int ARM64_SYSREG_ICH_VTR_EL2 = 0xE659;
	public static final int ARM64_SYSREG_ID_AA64AFR0_EL1 = 0xC02C;
	public static final int ARM64_SYSREG_ID_AA64AFR1_EL1 = 0xC02D;
	public static final int ARM64_SYSREG_ID_AA64DFR0_EL1 = 0xC028;
	public static final int ARM64_SYSREG_ID_AA64DFR1_EL1 = 0xC029;
	public static final int ARM64_SYSREG_ID_AA64ISAR0_EL1 = 0xC030;
	public static final int ARM64_SYSREG_ID_AA64ISAR1_EL1 = 0xC031;
	public static final int ARM64_SYSREG_ID_AA64ISAR2_EL1 = 0xC032;
	public static final int ARM64_SYSREG_ID_AA64MMFR0_EL1 = 0xC038;
	public static final int ARM64_SYSREG_ID_AA64MMFR1_EL1 = 0xC039;
	public static final int ARM64_SYSREG_ID_AA64MMFR2_EL1 = 0xC03A;
	public static final int ARM64_SYSREG_ID_AA64PFR0_EL1 = 0xC020;
	public static final int ARM64_SYSREG_ID_AA64PFR1_EL1 = 0xC021;
	public static final int ARM64_SYSREG_ID_AA64SMFR0_EL1 = 0xC025;
	public static final int ARM64_SYSREG_ID_AA64ZFR0_EL1 = 0xC024;
	public static final int ARM64_SYSREG_ID_AFR0_EL1 = 0xC00B;
	public static final int ARM64_SYSREG_ID_DFR0_EL1 = 0xC00A;
	public static final int ARM64_SYSREG_ID_ISAR0_EL1 = 0xC010;
	public static final int ARM64_SYSREG_ID_ISAR1_EL1 = 0xC011;
	public static final int ARM64_SYSREG_ID_ISAR2_EL1 = 0xC012;
	public static final int ARM64_SYSREG_ID_ISAR3_EL1 = 0xC013;
	public static final int ARM64_SYSREG_ID_ISAR4_EL1 = 0xC014;
	public static final int ARM64_SYSREG_ID_ISAR5_EL1 = 0xC015;
	public static final int ARM64_SYSREG_ID_ISAR6_EL1 = 0xC017;
	public static final int ARM64_SYSREG_ID_MMFR0_EL1 = 0xC00C;
	public static final int ARM64_SYSREG_ID_MMFR1_EL1 = 0xC00D;
	public static final int ARM64_SYSREG_ID_MMFR2_EL1 = 0xC00E;
	public static final int ARM64_SYSREG_ID_MMFR3_EL1 = 0xC00F;
	public static final int ARM64_SYSREG_ID_MMFR4_EL1 = 0xC016;
	public static final int ARM64_SYSREG_ID_MMFR5_EL1 = 0xC01E;
	public static final int ARM64_SYSREG_ID_PFR0_EL1 = 0xC008;
	public static final int ARM64_SYSREG_ID_PFR1_EL1 = 0xC009;
	public static final int ARM64_SYSREG_ID_PFR2_EL1 = 0xC01C;
	public static final int ARM64_SYSREG_IFSR32_EL2 = 0xE281;
	public static final int ARM64_SYSREG_ISR_EL1 = 0xC608;
	public static final int ARM64_SYSREG_LORC_EL1 = 0xC523;
	public static final int ARM64_SYSREG_LOREA_EL1 = 0xC521;
	public static final int ARM64_SYSREG_LORID_EL1 = 0xC527;
	public static final int ARM64_SYSREG_LORN_EL1 = 0xC522;
	public static final int ARM64_SYSREG_LORSA_EL1 = 0xC520;
	public static final int ARM64_SYSREG_MAIR_EL1 = 0xC510;
	public static final int ARM64_SYSREG_MAIR_EL12 = 0xED10;
	public static final int ARM64_SYSREG_MAIR_EL2 = 0xE510;
	public static final int ARM64_SYSREG_MAIR_EL3 = 0xF510;
	public static final int ARM64_SYSREG_MDCCINT_EL1 = 0x8010;
	public static final int ARM64_SYSREG_MDCCSR_EL0 = 0x9808;
	public static final int ARM64_SYSREG_MDCR_EL2 = 0xE089;
	public static final int ARM64_SYSREG_MDCR_EL3 = 0xF099;
	public static final int ARM64_SYSREG_MDRAR_EL1 = 0x8080;
	public static final int ARM64_SYSREG_MDSCR_EL1 = 0x8012;
	public static final int ARM64_SYSREG_MFAR_EL3 = 0xF305;
	public static final int ARM64_SYSREG_MIDR_EL1 = 0xC000;
	public static final int ARM64_SYSREG_MPAM0_EL1 = 0xC529;
	public static final int ARM64_SYSREG_MPAM1_EL1 = 0xC528;
	public static final int ARM64_SYSREG_MPAM1_EL12 = 0xED28;
	public static final int ARM64_SYSREG_MPAM2_EL2 = 0xE528;
	public static final int ARM64_SYSREG_MPAM3_EL3 = 0xF528;
	public static final int ARM64_SYSREG_MPAMHCR_EL2 = 0xE520;
	public static final int ARM64_SYSREG_MPAMIDR_EL1 = 0xC524;
	public static final int ARM64_SYSREG_MPAMSM_EL1 = 0xC52B;
	public static final int ARM64_SYSREG_MPAMVPM0_EL2 = 0xE530;
	public static final int ARM64_SYSREG_MPAMVPM1_EL2 = 0xE531;
	public static final int ARM64_SYSREG_MPAMVPM2_EL2 = 0xE532;
	public static final int ARM64_SYSREG_MPAMVPM3_EL2 = 0xE533;
	public static final int ARM64_SYSREG_MPAMVPM4_EL2 = 0xE534;
	public static final int ARM64_SYSREG_MPAMVPM5_EL2 = 0xE535;
	public static final int ARM64_SYSREG_MPAMVPM6_EL2 = 0xE536;
	public static final int ARM64_SYSREG_MPAMVPM7_EL2 = 0xE537;
	public static final int ARM64_SYSREG_MPAMVPMV_EL2 = 0xE521;
	public static final int ARM64_SYSREG_MPIDR_EL1 = 0xC005;
	public static final int ARM64_SYSREG_MPUIR_EL1 = 0xC004;
	public static final int ARM64_SYSREG_MPUIR_EL2 = 0xE004;
	public static final int ARM64_SYSREG_MVFR0_EL1 = 0xC018;
	public static final int ARM64_SYSREG_MVFR1_EL1 = 0xC019;
	public static final int ARM64_SYSREG_MVFR2_EL1 = 0xC01A;
	public static final int ARM64_SYSREG_NZCV = 0xDA10;
	public static final int ARM64_SYSREG_OSDLR_EL1 = 0x809C;
	public static final int ARM64_SYSREG_OSDTRRX_EL1 = 0x8002;
	public static final int ARM64_SYSREG_OSDTRTX_EL1 = 0x801A;
	public static final int ARM64_SYSREG_OSECCR_EL1 = 0x8032;
	public static final int ARM64_SYSREG_OSLAR_EL1 = 0x8084;
	public static final int ARM64_SYSREG_OSLSR_EL1 = 0x808C;
	public static final int ARM64_SYSREG_PAN = 0xC213;
	public static final int ARM64_SYSREG_PAR_EL1 = 0xC3A0;
	public static final int ARM64_SYSREG_PMBIDR_EL1 = 0xC4D7;
	public static final int ARM64_SYSREG_PMBLIMITR_EL1 = 0xC4D0;
	public static final int ARM64_SYSREG_PMBPTR_EL1 = 0xC4D1;
	public static final int ARM64_SYSREG_PMBSR_EL1 = 0xC4D3;
	public static final int ARM64_SYSREG_PMCCFILTR_EL0 = 0xDF7F;
	public static final int ARM64_SYSREG_PMCCNTR_EL0 = 0xDCE8;
	public static final int ARM64_SYSREG_PMCEID0_EL0 = 0xDCE6;
	public static final int ARM64_SYSREG_PMCEID1_EL0 = 0xDCE7;
	public static final int ARM64_SYSREG_PMCNTENCLR_EL0 = 0xDCE2;
	public static final int ARM64_SYSREG_PMCNTENSET_EL0 = 0xDCE1;
	public static final int ARM64_SYSREG_PMCR_EL0 = 0xDCE0;
	public static final int ARM64_SYSREG_PMEVCNTR0_EL0 = 0xDF40;
	public static final int ARM64_SYSREG_PMEVCNTR10_EL0 = 0xDF4A;
	public static final int ARM64_SYSREG_PMEVCNTR11_EL0 = 0xDF4B;
	public static final int ARM64_SYSREG_PMEVCNTR12_EL0 = 0xDF4C;
	public static final int ARM64_SYSREG_PMEVCNTR13_EL0 = 0xDF4D;
	public static final int ARM64_SYSREG_PMEVCNTR14_EL0 = 0xDF4E;
	public static final int ARM64_SYSREG_PMEVCNTR15_EL0 = 0xDF4F;
	public static final int ARM64_SYSREG_PMEVCNTR16_EL0 = 0xDF50;
	public static final int ARM64_SYSREG_PMEVCNTR17_EL0 = 0xDF51;
	public static final int ARM64_SYSREG_PMEVCNTR18_EL0 = 0xDF52;
	public static final int ARM64_SYSREG_PMEVCNTR19_EL0 = 0xDF53;
	public static final int ARM64_SYSREG_PMEVCNTR1_EL0 = 0xDF41;
	public static final int ARM64_SYSREG_PMEVCNTR20_EL0 = 0xDF54;
	public static final int ARM64_SYSREG_PMEVCNTR21_EL0 = 0xDF55;
	public static final int ARM64_SYSREG_PMEVCNTR22_EL0 = 0xDF56;
	public static final int ARM64_SYSREG_PMEVCNTR23_EL0 = 0xDF57;
	public static final int ARM64_SYSREG_PMEVCNTR24_EL0 = 0xDF58;
	public static final int ARM64_SYSREG_PMEVCNTR25_EL0 = 0xDF59;
	public static final int ARM64_SYSREG_PMEVCNTR26_EL0 = 0xDF5A;
	public static final int ARM64_SYSREG_PMEVCNTR27_EL0 = 0xDF5B;
	public static final int ARM64_SYSREG_PMEVCNTR28_EL0 = 0xDF5C;
	public static final int ARM64_SYSREG_PMEVCNTR29_EL0 = 0xDF5D;
	public static final int ARM64_SYSREG_PMEVCNTR2_EL0 = 0xDF42;
	public static final int ARM64_SYSREG_PMEVCNTR30_EL0 = 0xDF5E;
	public static final int ARM64_SYSREG_PMEVCNTR3_EL0 = 0xDF43;
	public static final int ARM64_SYSREG_PMEVCNTR4_EL0 = 0xDF44;
	public static final int ARM64_SYSREG_PMEVCNTR5_EL0 = 0xDF45;
	public static final int ARM64_SYSREG_PMEVCNTR6_EL0 = 0xDF46;
	public static final int ARM64_SYSREG_PMEVCNTR7_EL0 = 0xDF47;
	public static final int ARM64_SYSREG_PMEVCNTR8_EL0 = 0xDF48;
	public static final int ARM64_SYSREG_PMEVCNTR9_EL0 = 0xDF49;
	public static final int ARM64_SYSREG_PMEVTYPER0_EL0 = 0xDF60;
	public static final int ARM64_SYSREG_PMEVTYPER10_EL0 = 0xDF6A;
	public static final int ARM64_SYSREG_PMEVTYPER11_EL0 = 0xDF6B;
	public static final int ARM64_SYSREG_PMEVTYPER12_EL0 = 0xDF6C;
	public static final int ARM64_SYSREG_PMEVTYPER13_EL0 = 0xDF6D;
	public static final int ARM64_SYSREG_PMEVTYPER14_EL0 = 0xDF6E;
	public static final int ARM64_SYSREG_PMEVTYPER15_EL0 = 0xDF6F;
	public static final int ARM64_SYSREG_PMEVTYPER16_EL0 = 0xDF70;
	public static final int ARM64_SYSREG_PMEVTYPER17_EL0 = 0xDF71;
	public static final int ARM64_SYSREG_PMEVTYPER18_EL0 = 0xDF72;
	public static final int ARM64_SYSREG_PMEVTYPER19_EL0 = 0xDF73;
	public static final int ARM64_SYSREG_PMEVTYPER1_EL0 = 0xDF61;
	public static final int ARM64_SYSREG_PMEVTYPER20_EL0 = 0xDF74;
	public static final int ARM64_SYSREG_PMEVTYPER21_EL0 = 0xDF75;
	public static final int ARM64_SYSREG_PMEVTYPER22_EL0 = 0xDF76;
	public static final int ARM64_SYSREG_PMEVTYPER23_EL0 = 0xDF77;
	public static final int ARM64_SYSREG_PMEVTYPER24_EL0 = 0xDF78;
	public static final int ARM64_SYSREG_PMEVTYPER25_EL0 = 0xDF79;
	public static final int ARM64_SYSREG_PMEVTYPER26_EL0 = 0xDF7A;
	public static final int ARM64_SYSREG_PMEVTYPER27_EL0 = 0xDF7B;
	public static final int ARM64_SYSREG_PMEVTYPER28_EL0 = 0xDF7C;
	public static final int ARM64_SYSREG_PMEVTYPER29_EL0 = 0xDF7D;
	public static final int ARM64_SYSREG_PMEVTYPER2_EL0 = 0xDF62;
	public static final int ARM64_SYSREG_PMEVTYPER30_EL0 = 0xDF7E;
	public static final int ARM64_SYSREG_PMEVTYPER3_EL0 = 0xDF63;
	public static final int ARM64_SYSREG_PMEVTYPER4_EL0 = 0xDF64;
	public static final int ARM64_SYSREG_PMEVTYPER5_EL0 = 0xDF65;
	public static final int ARM64_SYSREG_PMEVTYPER6_EL0 = 0xDF66;
	public static final int ARM64_SYSREG_PMEVTYPER7_EL0 = 0xDF67;
	public static final int ARM64_SYSREG_PMEVTYPER8_EL0 = 0xDF68;
	public static final int ARM64_SYSREG_PMEVTYPER9_EL0 = 0xDF69;
	public static final int ARM64_SYSREG_PMINTENCLR_EL1 = 0xC4F2;
	public static final int ARM64_SYSREG_PMINTENSET_EL1 = 0xC4F1;
	public static final int ARM64_SYSREG_PMMIR_EL1 = 0xC4F6;
	public static final int ARM64_SYSREG_PMOVSCLR_EL0 = 0xDCE3;
	public static final int ARM64_SYSREG_PMOVSSET_EL0 = 0xDCF3;
	public static final int ARM64_SYSREG_PMSCR_EL1 = 0xC4C8;
	public static final int ARM64_SYSREG_PMSCR_EL12 = 0xECC8;
	public static final int ARM64_SYSREG_PMSCR_EL2 = 0xE4C8;
	public static final int ARM64_SYSREG_PMSELR_EL0 = 0xDCE5;
	public static final int ARM64_SYSREG_PMSEVFR_EL1 = 0xC4CD;
	public static final int ARM64_SYSREG_PMSFCR_EL1 = 0xC4CC;
	public static final int ARM64_SYSREG_PMSICR_EL1 = 0xC4CA;
	public static final int ARM64_SYSREG_PMSIDR_EL1 = 0xC4CF;
	public static final int ARM64_SYSREG_PMSIRR_EL1 = 0xC4CB;
	public static final int ARM64_SYSREG_PMSLATFR_EL1 = 0xC4CE;
	public static final int ARM64_SYSREG_PMSNEVFR_EL1 = 0xC4C9;
	public static final int ARM64_SYSREG_PMSWINC_EL0 = 0xDCE4;
	public static final int ARM64_SYSREG_PMUSERENR_EL0 = 0xDCF0;
	public static final int ARM64_SYSREG_PMXEVCNTR_EL0 = 0xDCEA;
	public static final int ARM64_SYSREG_PMXEVTYPER_EL0 = 0xDCE9;
	public static final int ARM64_SYSREG_PRBAR10_EL1 = 0xC368;
	public static final int ARM64_SYSREG_PRBAR10_EL2 = 0xE368;
	public static final int ARM64_SYSREG_PRBAR11_EL1 = 0xC36C;
	public static final int ARM64_SYSREG_PRBAR11_EL2 = 0xE36C;
	public static final int ARM64_SYSREG_PRBAR12_EL1 = 0xC370;
	public static final int ARM64_SYSREG_PRBAR12_EL2 = 0xE370;
	public static final int ARM64_SYSREG_PRBAR13_EL1 = 0xC374;
	public static final int ARM64_SYSREG_PRBAR13_EL2 = 0xE374;
	public static final int ARM64_SYSREG_PRBAR14_EL1 = 0xC378;
	public static final int ARM64_SYSREG_PRBAR14_EL2 = 0xE378;
	public static final int ARM64_SYSREG_PRBAR15_EL1 = 0xC37C;
	public static final int ARM64_SYSREG_PRBAR15_EL2 = 0xE37C;
	public static final int ARM64_SYSREG_PRBAR1_EL1 = 0xC344;
	public static final int ARM64_SYSREG_PRBAR1_EL2 = 0xE344;
	public static final int ARM64_SYSREG_PRBAR2_EL1 = 0xC348;
	public static final int ARM64_SYSREG_PRBAR2_EL2 = 0xE348;
	public static final int ARM64_SYSREG_PRBAR3_EL1 = 0xC34C;
	public static final int ARM64_SYSREG_PRBAR3_EL2 = 0xE34C;
	public static final int ARM64_SYSREG_PRBAR4_EL1 = 0xC350;
	public static final int ARM64_SYSREG_PRBAR4_EL2 = 0xE350;
	public static final int ARM64_SYSREG_PRBAR5_EL1 = 0xC354;
	public static final int ARM64_SYSREG_PRBAR5_EL2 = 0xE354;
	public static final int ARM64_SYSREG_PRBAR6_EL1 = 0xC358;
	public static final int ARM64_SYSREG_PRBAR6_EL2 = 0xE358;
	public static final int ARM64_SYSREG_PRBAR7_EL1 = 0xC35C;
	public static final int ARM64_SYSREG_PRBAR7_EL2 = 0xE35C;
	public static final int ARM64_SYSREG_PRBAR8_EL1 = 0xC360;
	public static final int ARM64_SYSREG_PRBAR8_EL2 = 0xE360;
	public static final int ARM64_SYSREG_PRBAR9_EL1 = 0xC364;
	public static final int ARM64_SYSREG_PRBAR9_EL2 = 0xE364;
	public static final int ARM64_SYSREG_PRBAR_EL1 = 0xC340;
	public static final int ARM64_SYSREG_PRBAR_EL2 = 0xE340;
	public static final int ARM64_SYSREG_PRENR_EL1 = 0xC309;
	public static final int ARM64_SYSREG_PRENR_EL2 = 0xE309;
	public static final int ARM64_SYSREG_PRLAR10_EL1 = 0xC369;
	public static final int ARM64_SYSREG_PRLAR10_EL2 = 0xE369;
	public static final int ARM64_SYSREG_PRLAR11_EL1 = 0xC36D;
	public static final int ARM64_SYSREG_PRLAR11_EL2 = 0xE36D;
	public static final int ARM64_SYSREG_PRLAR12_EL1 = 0xC371;
	public static final int ARM64_SYSREG_PRLAR12_EL2 = 0xE371;
	public static final int ARM64_SYSREG_PRLAR13_EL1 = 0xC375;
	public static final int ARM64_SYSREG_PRLAR13_EL2 = 0xE375;
	public static final int ARM64_SYSREG_PRLAR14_EL1 = 0xC379;
	public static final int ARM64_SYSREG_PRLAR14_EL2 = 0xE379;
	public static final int ARM64_SYSREG_PRLAR15_EL1 = 0xC37D;
	public static final int ARM64_SYSREG_PRLAR15_EL2 = 0xE37D;
	public static final int ARM64_SYSREG_PRLAR1_EL1 = 0xC345;
	public static final int ARM64_SYSREG_PRLAR1_EL2 = 0xE345;
	public static final int ARM64_SYSREG_PRLAR2_EL1 = 0xC349;
	public static final int ARM64_SYSREG_PRLAR2_EL2 = 0xE349;
	public static final int ARM64_SYSREG_PRLAR3_EL1 = 0xC34D;
	public static final int ARM64_SYSREG_PRLAR3_EL2 = 0xE34D;
	public static final int ARM64_SYSREG_PRLAR4_EL1 = 0xC351;
	public static final int ARM64_SYSREG_PRLAR4_EL2 = 0xE351;
	public static final int ARM64_SYSREG_PRLAR5_EL1 = 0xC355;
	public static final int ARM64_SYSREG_PRLAR5_EL2 = 0xE355;
	public static final int ARM64_SYSREG_PRLAR6_EL1 = 0xC359;
	public static final int ARM64_SYSREG_PRLAR6_EL2 = 0xE359;
	public static final int ARM64_SYSREG_PRLAR7_EL1 = 0xC35D;
	public static final int ARM64_SYSREG_PRLAR7_EL2 = 0xE35D;
	public static final int ARM64_SYSREG_PRLAR8_EL1 = 0xC361;
	public static final int ARM64_SYSREG_PRLAR8_EL2 = 0xE361;
	public static final int ARM64_SYSREG_PRLAR9_EL1 = 0xC365;
	public static final int ARM64_SYSREG_PRLAR9_EL2 = 0xE365;
	public static final int ARM64_SYSREG_PRLAR_EL1 = 0xC341;
	public static final int ARM64_SYSREG_PRLAR_EL2 = 0xE341;
	public static final int ARM64_SYSREG_PRSELR_EL1 = 0xC311;
	public static final int ARM64_SYSREG_PRSELR_EL2 = 0xE311;
	public static final int ARM64_SYSREG_REVIDR_EL1 = 0xC006;
	public static final int ARM64_SYSREG_RGSR_EL1 = 0xC085;
	public static final int ARM64_SYSREG_RMR_EL1 = 0xC602;
	public static final int ARM64_SYSREG_RMR_EL2 = 0xE602;
	public static final int ARM64_SYSREG_RMR_EL3 = 0xF602;
	public static final int ARM64_SYSREG_RNDR = 0xD920;
	public static final int ARM64_SYSREG_RNDRRS = 0xD921;
	public static final int ARM64_SYSREG_RVBAR_EL1 = 0xC601;
	public static final int ARM64_SYSREG_RVBAR_EL2 = 0xE601;
	public static final int ARM64_SYSREG_RVBAR_EL3 = 0xF601;
	public static final int ARM64_SYSREG_SCR_EL3 = 0xF088;
	public static final int ARM64_SYSREG_SCTLR_EL1 = 0xC080;
	public static final int ARM64_SYSREG_SCTLR_EL12 = 0xE880;
	public static final int ARM64_SYSREG_SCTLR_EL2 = 0xE080;
	public static final int ARM64_SYSREG_SCTLR_EL3 = 0xF080;
	public static final int ARM64_SYSREG_SCXTNUM_EL0 = 0xDE87;
	public static final int ARM64_SYSREG_SCXTNUM_EL1 = 0xC687;
	public static final int ARM64_SYSREG_SCXTNUM_EL12 = 0xEE87;
	public static final int ARM64_SYSREG_SCXTNUM_EL2 = 0xE687;
	public static final int ARM64_SYSREG_SCXTNUM_EL3 = 0xF687;
	public static final int ARM64_SYSREG_SDER32_EL2 = 0xE099;
	public static final int ARM64_SYSREG_SDER32_EL3 = 0xF089;
	public static final int ARM64_SYSREG_SMCR_EL1 = 0xC096;
	public static final int ARM64_SYSREG_SMCR_EL12 = 0xE896;
	public static final int ARM64_SYSREG_SMCR_EL2 = 0xE096;
	public static final int ARM64_SYSREG_SMCR_EL3 = 0xF096;
	public static final int ARM64_SYSREG_SMIDR_EL1 = 0xC806;
	public static final int ARM64_SYSREG_SMPRIMAP_EL2 = 0xE095;
	public static final int ARM64_SYSREG_SMPRI_EL1 = 0xC094;
	public static final int ARM64_SYSREG_SPSEL = 0xC210;
	public static final int ARM64_SYSREG_SPSR_ABT = 0xE219;
	public static final int ARM64_SYSREG_SPSR_EL1 = 0xC200;
	public static final int ARM64_SYSREG_SPSR_EL12 = 0xEA00;
	public static final int ARM64_SYSREG_SPSR_EL2 = 0xE200;
	public static final int ARM64_SYSREG_SPSR_EL3 = 0xF200;
	public static final int ARM64_SYSREG_SPSR_FIQ = 0xE21B;
	public static final int ARM64_SYSREG_SPSR_IRQ = 0xE218;
	public static final int ARM64_SYSREG_SPSR_UND = 0xE21A;
	public static final int ARM64_SYSREG_SP_EL0 = 0xC208;
	public static final int ARM64_SYSREG_SP_EL1 = 0xE208;
	public static final int ARM64_SYSREG_SP_EL2 = 0xF208;
	public static final int ARM64_SYSREG_SSBS = 0xDA16;
	public static final int ARM64_SYSREG_SVCR = 0xDA12;
	public static final int ARM64_SYSREG_TCO = 0xDA17;
	public static final int ARM64_SYSREG_TCR_EL1 = 0xC102;
	public static final int ARM64_SYSREG_TCR_EL12 = 0xE902;
	public static final int ARM64_SYSREG_TCR_EL2 = 0xE102;
	public static final int ARM64_SYSREG_TCR_EL3 = 0xF102;
	public static final int ARM64_SYSREG_TEECR32_EL1 = 0x9000;
	public static final int ARM64_SYSREG_TEEHBR32_EL1 = 0x9080;
	public static final int ARM64_SYSREG_TFSRE0_EL1 = 0xC2B1;
	public static final int ARM64_SYSREG_TFSR_EL1 = 0xC2B0;
	public static final int ARM64_SYSREG_TFSR_EL12 = 0xEAB0;
	public static final int ARM64_SYSREG_TFSR_EL2 = 0xE2B0;
	public static final int ARM64_SYSREG_TFSR_EL3 = 0xF2B0;
	public static final int ARM64_SYSREG_TPIDR2_EL0 = 0xDE85;
	public static final int ARM64_SYSREG_TPIDRRO_EL0 = 0xDE83;
	public static final int ARM64_SYSREG_TPIDR_EL0 = 0xDE82;
	public static final int ARM64_SYSREG_TPIDR_EL1 = 0xC684;
	public static final int ARM64_SYSREG_TPIDR_EL2 = 0xE682;
	public static final int ARM64_SYSREG_TPIDR_EL3 = 0xF682;
	public static final int ARM64_SYSREG_TRBBASER_EL1 = 0xC4DA;
	public static final int ARM64_SYSREG_TRBIDR_EL1 = 0xC4DF;
	public static final int ARM64_SYSREG_TRBLIMITR_EL1 = 0xC4D8;
	public static final int ARM64_SYSREG_TRBMAR_EL1 = 0xC4DC;
	public static final int ARM64_SYSREG_TRBPTR_EL1 = 0xC4D9;
	public static final int ARM64_SYSREG_TRBSR_EL1 = 0xC4DB;
	public static final int ARM64_SYSREG_TRBTRG_EL1 = 0xC4DE;
	public static final int ARM64_SYSREG_TRCACATR0 = 0x8902;
	public static final int ARM64_SYSREG_TRCACATR1 = 0x8912;
	public static final int ARM64_SYSREG_TRCACATR10 = 0x8923;
	public static final int ARM64_SYSREG_TRCACATR11 = 0x8933;
	public static final int ARM64_SYSREG_TRCACATR12 = 0x8943;
	public static final int ARM64_SYSREG_TRCACATR13 = 0x8953;
	public static final int ARM64_SYSREG_TRCACATR14 = 0x8963;
	public static final int ARM64_SYSREG_TRCACATR15 = 0x8973;
	public static final int ARM64_SYSREG_TRCACATR2 = 0x8922;
	public static final int ARM64_SYSREG_TRCACATR3 = 0x8932;
	public static final int ARM64_SYSREG_TRCACATR4 = 0x8942;
	public static final int ARM64_SYSREG_TRCACATR5 = 0x8952;
	public static final int ARM64_SYSREG_TRCACATR6 = 0x8962;
	public static final int ARM64_SYSREG_TRCACATR7 = 0x8972;
	public static final int ARM64_SYSREG_TRCACATR8 = 0x8903;
	public static final int ARM64_SYSREG_TRCACATR9 = 0x8913;
	public static final int ARM64_SYSREG_TRCACVR0 = 0x8900;
	public static final int ARM64_SYSREG_TRCACVR1 = 0x8910;
	public static final int ARM64_SYSREG_TRCACVR10 = 0x8921;
	public static final int ARM64_SYSREG_TRCACVR11 = 0x8931;
	public static final int ARM64_SYSREG_TRCACVR12 = 0x8941;
	public static final int ARM64_SYSREG_TRCACVR13 = 0x8951;
	public static final int ARM64_SYSREG_TRCACVR14 = 0x8961;
	public static final int ARM64_SYSREG_TRCACVR15 = 0x8971;
	public static final int ARM64_SYSREG_TRCACVR2 = 0x8920;
	public static final int ARM64_SYSREG_TRCACVR3 = 0x8930;
	public static final int ARM64_SYSREG_TRCACVR4 = 0x8940;
	public static final int ARM64_SYSREG_TRCACVR5 = 0x8950;
	public static final int ARM64_SYSREG_TRCACVR6 = 0x8960;
	public static final int ARM64_SYSREG_TRCACVR7 = 0x8970;
	public static final int ARM64_SYSREG_TRCACVR8 = 0x8901;
	public static final int ARM64_SYSREG_TRCACVR9 = 0x8911;
	public static final int ARM64_SYSREG_TRCAUTHSTATUS = 0x8BF6;
	public static final int ARM64_SYSREG_TRCAUXCTLR = 0x8830;
	public static final int ARM64_SYSREG_TRCBBCTLR = 0x8878;
	public static final int ARM64_SYSREG_TRCCCCTLR = 0x8870;
	public static final int ARM64_SYSREG_TRCCIDCCTLR0 = 0x8982;
	public static final int ARM64_SYSREG_TRCCIDCCTLR1 = 0x898A;
	public static final int ARM64_SYSREG_TRCCIDCVR0 = 0x8980;
	public static final int ARM64_SYSREG_TRCCIDCVR1 = 0x8990;
	public static final int ARM64_SYSREG_TRCCIDCVR2 = 0x89A0;
	public static final int ARM64_SYSREG_TRCCIDCVR3 = 0x89B0;
	public static final int ARM64_SYSREG_TRCCIDCVR4 = 0x89C0;
	public static final int ARM64_SYSREG_TRCCIDCVR5 = 0x89D0;
	public static final int ARM64_SYSREG_TRCCIDCVR6 = 0x89E0;
	public static final int ARM64_SYSREG_TRCCIDCVR7 = 0x89F0;
	public static final int ARM64_SYSREG_TRCCIDR0 = 0x8BE7;
	public static final int ARM64_SYSREG_TRCCIDR1 = 0x8BEF;
	public static final int ARM64_SYSREG_TRCCIDR2 = 0x8BF7;
	public static final int ARM64_SYSREG_TRCCIDR3 = 0x8BFF;
	public static final int ARM64_SYSREG_TRCCLAIMCLR = 0x8BCE;
	public static final int ARM64_SYSREG_TRCCLAIMSET = 0x8BC6;
	public static final int ARM64_SYSREG_TRCCNTCTLR0 = 0x8825;
	public static final int ARM64_SYSREG_TRCCNTCTLR1 = 0x882D;
	public static final int ARM64_SYSREG_TRCCNTCTLR2 = 0x8835;
	public static final int ARM64_SYSREG_TRCCNTCTLR3 = 0x883D;
	public static final int ARM64_SYSREG_TRCCNTRLDVR0 = 0x8805;
	public static final int ARM64_SYSREG_TRCCNTRLDVR1 = 0x880D;
	public static final int ARM64_SYSREG_TRCCNTRLDVR2 = 0x8815;
	public static final int ARM64_SYSREG_TRCCNTRLDVR3 = 0x881D;
	public static final int ARM64_SYSREG_TRCCNTVR0 = 0x8845;
	public static final int ARM64_SYSREG_TRCCNTVR1 = 0x884D;
	public static final int ARM64_SYSREG_TRCCNTVR2 = 0x8855;
	public static final int ARM64_SYSREG_TRCCNTVR3 = 0x885D;
	public static final int ARM64_SYSREG_TRCCONFIGR = 0x8820;
	public static final int ARM64_SYSREG_TRCDEVAFF0 = 0x8BD6;
	public static final int ARM64_SYSREG_TRCDEVAFF1 = 0x8BDE;
	public static final int ARM64_SYSREG_TRCDEVARCH = 0x8BFE;
	public static final int ARM64_SYSREG_TRCDEVID = 0x8B97;
	public static final int ARM64_SYSREG_TRCDEVTYPE = 0x8B9F;
	public static final int ARM64_SYSREG_TRCDVCMR0 = 0x8906;
	public static final int ARM64_SYSREG_TRCDVCMR1 = 0x8926;
	public static final int ARM64_SYSREG_TRCDVCMR2 = 0x8946;
	public static final int ARM64_SYSREG_TRCDVCMR3 = 0x8966;
	public static final int ARM64_SYSREG_TRCDVCMR4 = 0x8907;
	public static final int ARM64_SYSREG_TRCDVCMR5 = 0x8927;
	public static final int ARM64_SYSREG_TRCDVCMR6 = 0x8947;
	public static final int ARM64_SYSREG_TRCDVCMR7 = 0x8967;
	public static final int ARM64_SYSREG_TRCDVCVR0 = 0x8904;
	public static final int ARM64_SYSREG_TRCDVCVR1 = 0x8924;
	public static final int ARM64_SYSREG_TRCDVCVR2 = 0x8944;
	public static final int ARM64_SYSREG_TRCDVCVR3 = 0x8964;
	public static final int ARM64_SYSREG_TRCDVCVR4 = 0x8905;
	public static final int ARM64_SYSREG_TRCDVCVR5 = 0x8925;
	public static final int ARM64_SYSREG_TRCDVCVR6 = 0x8945;
	public static final int ARM64_SYSREG_TRCDVCVR7 = 0x8965;
	public static final int ARM64_SYSREG_TRCEVENTCTL0R = 0x8840;
	public static final int ARM64_SYSREG_TRCEVENTCTL1R = 0x8848;
	public static final int ARM64_SYSREG_TRCEXTINSELR = 0x8844;
	public static final int ARM64_SYSREG_TRCEXTINSELR0 = 0x8844;
	public static final int ARM64_SYSREG_TRCEXTINSELR1 = 0x884C;
	public static final int ARM64_SYSREG_TRCEXTINSELR2 = 0x8854;
	public static final int ARM64_SYSREG_TRCEXTINSELR3 = 0x885C;
	public static final int ARM64_SYSREG_TRCIDR0 = 0x8847;
	public static final int ARM64_SYSREG_TRCIDR1 = 0x884F;
	public static final int ARM64_SYSREG_TRCIDR10 = 0x8816;
	public static final int ARM64_SYSREG_TRCIDR11 = 0x881E;
	public static final int ARM64_SYSREG_TRCIDR12 = 0x8826;
	public static final int ARM64_SYSREG_TRCIDR13 = 0x882E;
	public static final int ARM64_SYSREG_TRCIDR2 = 0x8857;
	public static final int ARM64_SYSREG_TRCIDR3 = 0x885F;
	public static final int ARM64_SYSREG_TRCIDR4 = 0x8867;
	public static final int ARM64_SYSREG_TRCIDR5 = 0x886F;
	public static final int ARM64_SYSREG_TRCIDR6 = 0x8877;
	public static final int ARM64_SYSREG_TRCIDR7 = 0x887F;
	public static final int ARM64_SYSREG_TRCIDR8 = 0x8806;
	public static final int ARM64_SYSREG_TRCIDR9 = 0x880E;
	public static final int ARM64_SYSREG_TRCIMSPEC0 = 0x8807;
	public static final int ARM64_SYSREG_TRCIMSPEC1 = 0x880F;
	public static final int ARM64_SYSREG_TRCIMSPEC2 = 0x8817;
	public static final int ARM64_SYSREG_TRCIMSPEC3 = 0x881F;
	public static final int ARM64_SYSREG_TRCIMSPEC4 = 0x8827;
	public static final int ARM64_SYSREG_TRCIMSPEC5 = 0x882F;
	public static final int ARM64_SYSREG_TRCIMSPEC6 = 0x8837;
	public static final int ARM64_SYSREG_TRCIMSPEC7 = 0x883F;
	public static final int ARM64_SYSREG_TRCITCTRL = 0x8B84;
	public static final int ARM64_SYSREG_TRCLAR = 0x8BE6;
	public static final int ARM64_SYSREG_TRCLSR = 0x8BEE;
	public static final int ARM64_SYSREG_TRCOSLAR = 0x8884;
	public static final int ARM64_SYSREG_TRCOSLSR = 0x888C;
	public static final int ARM64_SYSREG_TRCPDCR = 0x88A4;
	public static final int ARM64_SYSREG_TRCPDSR = 0x88AC;
	public static final int ARM64_SYSREG_TRCPIDR0 = 0x8BC7;
	public static final int ARM64_SYSREG_TRCPIDR1 = 0x8BCF;
	public static final int ARM64_SYSREG_TRCPIDR2 = 0x8BD7;
	public static final int ARM64_SYSREG_TRCPIDR3 = 0x8BDF;
	public static final int ARM64_SYSREG_TRCPIDR4 = 0x8BA7;
	public static final int ARM64_SYSREG_TRCPIDR5 = 0x8BAF;
	public static final int ARM64_SYSREG_TRCPIDR6 = 0x8BB7;
	public static final int ARM64_SYSREG_TRCPIDR7 = 0x8BBF;
	public static final int ARM64_SYSREG_TRCPRGCTLR = 0x8808;
	public static final int ARM64_SYSREG_TRCPROCSELR = 0x8810;
	public static final int ARM64_SYSREG_TRCQCTLR = 0x8809;
	public static final int ARM64_SYSREG_TRCRSCTLR10 = 0x88D0;
	public static final int ARM64_SYSREG_TRCRSCTLR11 = 0x88D8;
	public static final int ARM64_SYSREG_TRCRSCTLR12 = 0x88E0;
	public static final int ARM64_SYSREG_TRCRSCTLR13 = 0x88E8;
	public static final int ARM64_SYSREG_TRCRSCTLR14 = 0x88F0;
	public static final int ARM64_SYSREG_TRCRSCTLR15 = 0x88F8;
	public static final int ARM64_SYSREG_TRCRSCTLR16 = 0x8881;
	public static final int ARM64_SYSREG_TRCRSCTLR17 = 0x8889;
	public static final int ARM64_SYSREG_TRCRSCTLR18 = 0x8891;
	public static final int ARM64_SYSREG_TRCRSCTLR19 = 0x8899;
	public static final int ARM64_SYSREG_TRCRSCTLR2 = 0x8890;
	public static final int ARM64_SYSREG_TRCRSCTLR20 = 0x88A1;
	public static final int ARM64_SYSREG_TRCRSCTLR21 = 0x88A9;
	public static final int ARM64_SYSREG_TRCRSCTLR22 = 0x88B1;
	public static final int ARM64_SYSREG_TRCRSCTLR23 = 0x88B9;
	public static final int ARM64_SYSREG_TRCRSCTLR24 = 0x88C1;
	public static final int ARM64_SYSREG_TRCRSCTLR25 = 0x88C9;
	public static final int ARM64_SYSREG_TRCRSCTLR26 = 0x88D1;
	public static final int ARM64_SYSREG_TRCRSCTLR27 = 0x88D9;
	public static final int ARM64_SYSREG_TRCRSCTLR28 = 0x88E1;
	public static final int ARM64_SYSREG_TRCRSCTLR29 = 0x88E9;
	public static final int ARM64_SYSREG_TRCRSCTLR3 = 0x8898;
	public static final int ARM64_SYSREG_TRCRSCTLR30 = 0x88F1;
	public static final int ARM64_SYSREG_TRCRSCTLR31 = 0x88F9;
	public static final int ARM64_SYSREG_TRCRSCTLR4 = 0x88A0;
	public static final int ARM64_SYSREG_TRCRSCTLR5 = 0x88A8;
	public static final int ARM64_SYSREG_TRCRSCTLR6 = 0x88B0;
	public static final int ARM64_SYSREG_TRCRSCTLR7 = 0x88B8;
	public static final int ARM64_SYSREG_TRCRSCTLR8 = 0x88C0;
	public static final int ARM64_SYSREG_TRCRSCTLR9 = 0x88C8;
	public static final int ARM64_SYSREG_TRCRSR = 0x8850;
	public static final int ARM64_SYSREG_TRCSEQEVR0 = 0x8804;
	public static final int ARM64_SYSREG_TRCSEQEVR1 = 0x880C;
	public static final int ARM64_SYSREG_TRCSEQEVR2 = 0x8814;
	public static final int ARM64_SYSREG_TRCSEQRSTEVR = 0x8834;
	public static final int ARM64_SYSREG_TRCSEQSTR = 0x883C;
	public static final int ARM64_SYSREG_TRCSSCCR0 = 0x8882;
	public static final int ARM64_SYSREG_TRCSSCCR1 = 0x888A;
	public static final int ARM64_SYSREG_TRCSSCCR2 = 0x8892;
	public static final int ARM64_SYSREG_TRCSSCCR3 = 0x889A;
	public static final int ARM64_SYSREG_TRCSSCCR4 = 0x88A2;
	public static final int ARM64_SYSREG_TRCSSCCR5 = 0x88AA;
	public static final int ARM64_SYSREG_TRCSSCCR6 = 0x88B2;
	public static final int ARM64_SYSREG_TRCSSCCR7 = 0x88BA;
	public static final int ARM64_SYSREG_TRCSSCSR0 = 0x88C2;
	public static final int ARM64_SYSREG_TRCSSCSR1 = 0x88CA;
	public static final int ARM64_SYSREG_TRCSSCSR2 = 0x88D2;
	public static final int ARM64_SYSREG_TRCSSCSR3 = 0x88DA;
	public static final int ARM64_SYSREG_TRCSSCSR4 = 0x88E2;
	public static final int ARM64_SYSREG_TRCSSCSR5 = 0x88EA;
	public static final int ARM64_SYSREG_TRCSSCSR6 = 0x88F2;
	public static final int ARM64_SYSREG_TRCSSCSR7 = 0x88FA;
	public static final int ARM64_SYSREG_TRCSSPCICR0 = 0x8883;
	public static final int ARM64_SYSREG_TRCSSPCICR1 = 0x888B;
	public static final int ARM64_SYSREG_TRCSSPCICR2 = 0x8893;
	public static final int ARM64_SYSREG_TRCSSPCICR3 = 0x889B;
	public static final int ARM64_SYSREG_TRCSSPCICR4 = 0x88A3;
	public static final int ARM64_SYSREG_TRCSSPCICR5 = 0x88AB;
	public static final int ARM64_SYSREG_TRCSSPCICR6 = 0x88B3;
	public static final int ARM64_SYSREG_TRCSSPCICR7 = 0x88BB;
	public static final int ARM64_SYSREG_TRCSTALLCTLR = 0x8858;
	public static final int ARM64_SYSREG_TRCSTATR = 0x8818;
	public static final int ARM64_SYSREG_TRCSYNCPR = 0x8868;
	public static final int ARM64_SYSREG_TRCTRACEIDR = 0x8801;
	public static final int ARM64_SYSREG_TRCTSCTLR = 0x8860;
	public static final int ARM64_SYSREG_TRCVDARCCTLR = 0x8852;
	public static final int ARM64_SYSREG_TRCVDCTLR = 0x8842;
	public static final int ARM64_SYSREG_TRCVDSACCTLR = 0x884A;
	public static final int ARM64_SYSREG_TRCVICTLR = 0x8802;
	public static final int ARM64_SYSREG_TRCVIIECTLR = 0x880A;
	public static final int ARM64_SYSREG_TRCVIPCSSCTLR = 0x881A;
	public static final int ARM64_SYSREG_TRCVISSCTLR = 0x8812;
	public static final int ARM64_SYSREG_TRCVMIDCCTLR0 = 0x8992;
	public static final int ARM64_SYSREG_TRCVMIDCCTLR1 = 0x899A;
	public static final int ARM64_SYSREG_TRCVMIDCVR0 = 0x8981;
	public static final int ARM64_SYSREG_TRCVMIDCVR1 = 0x8991;
	public static final int ARM64_SYSREG_TRCVMIDCVR2 = 0x89A1;
	public static final int ARM64_SYSREG_TRCVMIDCVR3 = 0x89B1;
	public static final int ARM64_SYSREG_TRCVMIDCVR4 = 0x89C1;
	public static final int ARM64_SYSREG_TRCVMIDCVR5 = 0x89D1;
	public static final int ARM64_SYSREG_TRCVMIDCVR6 = 0x89E1;
	public static final int ARM64_SYSREG_TRCVMIDCVR7 = 0x89F1;
	public static final int ARM64_SYSREG_TRFCR_EL1 = 0xC091;
	public static final int ARM64_SYSREG_TRFCR_EL12 = 0xE891;
	public static final int ARM64_SYSREG_TRFCR_EL2 = 0xE091;
	public static final int ARM64_SYSREG_TTBR0_EL1 = 0xC100;
	public static final int ARM64_SYSREG_TTBR0_EL12 = 0xE900;
	public static final int ARM64_SYSREG_TTBR0_EL2 = 0xE100;
	public static final int ARM64_SYSREG_TTBR0_EL3 = 0xF100;
	public static final int ARM64_SYSREG_TTBR1_EL1 = 0xC101;
	public static final int ARM64_SYSREG_TTBR1_EL12 = 0xE901;
	public static final int ARM64_SYSREG_TTBR1_EL2 = 0xE101;
	public static final int ARM64_SYSREG_UAO = 0xC214;
	public static final int ARM64_SYSREG_VBAR_EL1 = 0xC600;
	public static final int ARM64_SYSREG_VBAR_EL12 = 0xEE00;
	public static final int ARM64_SYSREG_VBAR_EL2 = 0xE600;
	public static final int ARM64_SYSREG_VBAR_EL3 = 0xF600;
	public static final int ARM64_SYSREG_VDISR_EL2 = 0xE609;
	public static final int ARM64_SYSREG_VMPIDR_EL2 = 0xE005;
	public static final int ARM64_SYSREG_VNCR_EL2 = 0xE110;
	public static final int ARM64_SYSREG_VPIDR_EL2 = 0xE000;
	public static final int ARM64_SYSREG_VSCTLR_EL2 = 0xE100;
	public static final int ARM64_SYSREG_VSESR_EL2 = 0xE293;
	public static final int ARM64_SYSREG_VSTCR_EL2 = 0xE132;
	public static final int ARM64_SYSREG_VSTTBR_EL2 = 0xE130;
	public static final int ARM64_SYSREG_VTCR_EL2 = 0xE10A;
	public static final int ARM64_SYSREG_VTTBR_EL2 = 0xE108;
	public static final int ARM64_SYSREG_ZCR_EL1 = 0xC090;
	public static final int ARM64_SYSREG_ZCR_EL12 = 0xE890;
	public static final int ARM64_SYSREG_ZCR_EL2 = 0xE090;
	public static final int ARM64_SYSREG_ZCR_EL3 = 0xF090;

	public static final int ARM64_PSTATE_INVALID = 0;
	public static final int ARM64_PSTATE_SPSEL = 0x05;
	public static final int ARM64_PSTATE_DAIFSET = 0x1e;
	public static final int ARM64_PSTATE_DAIFCLR = 0x1f;
	public static final int ARM64_PSTATE_PAN = 0x4;
	public static final int ARM64_PSTATE_UAO = 0x3;
	public static final int ARM64_PSTATE_DIT = 0x1a;

	public static final int ARM64_VAS_INVALID = 0;
	public static final int ARM64_VAS_16B = 1;
	public static final int ARM64_VAS_8B = 2;
	public static final int ARM64_VAS_4B = 3;
	public static final int ARM64_VAS_1B = 4;
	public static final int ARM64_VAS_8H = 5;
	public static final int ARM64_VAS_4H = 6;
	public static final int ARM64_VAS_2H = 7;
	public static final int ARM64_VAS_1H = 8;
	public static final int ARM64_VAS_4S = 9;
	public static final int ARM64_VAS_2S = 10;
	public static final int ARM64_VAS_1S = 11;
	public static final int ARM64_VAS_2D = 12;
	public static final int ARM64_VAS_1D = 13;
	public static final int ARM64_VAS_1Q = 14;

	public static final int ARM64_BARRIER_INVALID = 0;
	public static final int ARM64_BARRIER_OSHLD = 0x1;
	public static final int ARM64_BARRIER_OSHST = 0x2;
	public static final int ARM64_BARRIER_OSH = 0x3;
	public static final int ARM64_BARRIER_NSHLD = 0x5;
	public static final int ARM64_BARRIER_NSHST = 0x6;
	public static final int ARM64_BARRIER_NSH = 0x7;
	public static final int ARM64_BARRIER_ISHLD = 0x9;
	public static final int ARM64_BARRIER_ISHST = 0xa;
	public static final int ARM64_BARRIER_ISH = 0xb;
	public static final int ARM64_BARRIER_LD = 0xd;
	public static final int ARM64_BARRIER_ST = 0xe;
	public static final int ARM64_BARRIER_SY = 0xf;

	public static final int ARM64_OP_INVALID = 0;
	public static final int ARM64_OP_REG = 1;
	public static final int ARM64_OP_IMM = 2;
	public static final int ARM64_OP_MEM = 3;
	public static final int ARM64_OP_FP = 4;
	public static final int ARM64_OP_CIMM = 64;
	public static final int ARM64_OP_REG_MRS = 65;
	public static final int ARM64_OP_REG_MSR = 66;
	public static final int ARM64_OP_PSTATE = 67;
	public static final int ARM64_OP_SYS = 68;
	public static final int ARM64_OP_SVCR = 69;
	public static final int ARM64_OP_PREFETCH = 70;
	public static final int ARM64_OP_BARRIER = 71;
	public static final int ARM64_OP_SME_INDEX = 72;

	public static final int ARM64_SYS_INVALID = 0;
	public static final int ARM64_TLBI_ALLE1 = 1;
	public static final int ARM64_TLBI_ALLE1IS = 2;
	public static final int ARM64_TLBI_ALLE1ISNXS = 3;
	public static final int ARM64_TLBI_ALLE1NXS = 4;
	public static final int ARM64_TLBI_ALLE1OS = 5;
	public static final int ARM64_TLBI_ALLE1OSNXS = 6;
	public static final int ARM64_TLBI_ALLE2 = 7;
	public static final int ARM64_TLBI_ALLE2IS = 8;
	public static final int ARM64_TLBI_ALLE2ISNXS = 9;
	public static final int ARM64_TLBI_ALLE2NXS = 10;
	public static final int ARM64_TLBI_ALLE2OS = 11;
	public static final int ARM64_TLBI_ALLE2OSNXS = 12;
	public static final int ARM64_TLBI_ALLE3 = 13;
	public static final int ARM64_TLBI_ALLE3IS = 14;
	public static final int ARM64_TLBI_ALLE3ISNXS = 15;
	public static final int ARM64_TLBI_ALLE3NXS = 16;
	public static final int ARM64_TLBI_ALLE3OS = 17;
	public static final int ARM64_TLBI_ALLE3OSNXS = 18;
	public static final int ARM64_TLBI_ASIDE1 = 19;
	public static final int ARM64_TLBI_ASIDE1IS = 20;
	public static final int ARM64_TLBI_ASIDE1ISNXS = 21;
	public static final int ARM64_TLBI_ASIDE1NXS = 22;
	public static final int ARM64_TLBI_ASIDE1OS = 23;
	public static final int ARM64_TLBI_ASIDE1OSNXS = 24;
	public static final int ARM64_TLBI_IPAS2E1 = 25;
	public static final int ARM64_TLBI_IPAS2E1IS = 26;
	public static final int ARM64_TLBI_IPAS2E1ISNXS = 27;
	public static final int ARM64_TLBI_IPAS2E1NXS = 28;
	public static final int ARM64_TLBI_IPAS2E1OS = 29;
	public static final int ARM64_TLBI_IPAS2E1OSNXS = 30;
	public static final int ARM64_TLBI_IPAS2LE1 = 31;
	public static final int ARM64_TLBI_IPAS2LE1IS = 32;
	public static final int ARM64_TLBI_IPAS2LE1ISNXS = 33;
	public static final int ARM64_TLBI_IPAS2LE1NXS = 34;
	public static final int ARM64_TLBI_IPAS2LE1OS = 35;
	public static final int ARM64_TLBI_IPAS2LE1OSNXS = 36;
	public static final int ARM64_TLBI_PAALL = 37;
	public static final int ARM64_TLBI_PAALLNXS = 38;
	public static final int ARM64_TLBI_PAALLOS = 39;
	public static final int ARM64_TLBI_PAALLOSNXS = 40;
	public static final int ARM64_TLBI_RIPAS2E1 = 41;
	public static final int ARM64_TLBI_RIPAS2E1IS = 42;
	public static final int ARM64_TLBI_RIPAS2E1ISNXS = 43;
	public static final int ARM64_TLBI_RIPAS2E1NXS = 44;
	public static final int ARM64_TLBI_RIPAS2E1OS = 45;
	public static final int ARM64_TLBI_RIPAS2E1OSNXS = 46;
	public static final int ARM64_TLBI_RIPAS2LE1 = 47;
	public static final int ARM64_TLBI_RIPAS2LE1IS = 48;
	public static final int ARM64_TLBI_RIPAS2LE1ISNXS = 49;
	public static final int ARM64_TLBI_RIPAS2LE1NXS = 50;
	public static final int ARM64_TLBI_RIPAS2LE1OS = 51;
	public static final int ARM64_TLBI_RIPAS2LE1OSNXS = 52;
	public static final int ARM64_TLBI_RPALOS = 53;
	public static final int ARM64_TLBI_RPALOSNXS = 54;
	public static final int ARM64_TLBI_RPAOS = 55;
	public static final int ARM64_TLBI_RPAOSNXS = 56;
	public static final int ARM64_TLBI_RVAAE1 = 57;
	public static final int ARM64_TLBI_RVAAE1IS = 58;
	public static final int ARM64_TLBI_RVAAE1ISNXS = 59;
	public static final int ARM64_TLBI_RVAAE1NXS = 60;
	public static final int ARM64_TLBI_RVAAE1OS = 61;
	public static final int ARM64_TLBI_RVAAE1OSNXS = 62;
	public static final int ARM64_TLBI_RVAALE1 = 63;
	public static final int ARM64_TLBI_RVAALE1IS = 64;
	public static final int ARM64_TLBI_RVAALE1ISNXS = 65;
	public static final int ARM64_TLBI_RVAALE1NXS = 66;
	public static final int ARM64_TLBI_RVAALE1OS = 67;
	public static final int ARM64_TLBI_RVAALE1OSNXS = 68;
	public static final int ARM64_TLBI_RVAE1 = 69;
	public static final int ARM64_TLBI_RVAE1IS = 70;
	public static final int ARM64_TLBI_RVAE1ISNXS = 71;
	public static final int ARM64_TLBI_RVAE1NXS = 72;
	public static final int ARM64_TLBI_RVAE1OS = 73;
	public static final int ARM64_TLBI_RVAE1OSNXS = 74;
	public static final int ARM64_TLBI_RVAE2 = 75;
	public static final int ARM64_TLBI_RVAE2IS = 76;
	public static final int ARM64_TLBI_RVAE2ISNXS = 77;
	public static final int ARM64_TLBI_RVAE2NXS = 78;
	public static final int ARM64_TLBI_RVAE2OS = 79;
	public static final int ARM64_TLBI_RVAE2OSNXS = 80;
	public static final int ARM64_TLBI_RVAE3 = 81;
	public static final int ARM64_TLBI_RVAE3IS = 82;
	public static final int ARM64_TLBI_RVAE3ISNXS = 83;
	public static final int ARM64_TLBI_RVAE3NXS = 84;
	public static final int ARM64_TLBI_RVAE3OS = 85;
	public static final int ARM64_TLBI_RVAE3OSNXS = 86;
	public static final int ARM64_TLBI_RVALE1 = 87;
	public static final int ARM64_TLBI_RVALE1IS = 88;
	public static final int ARM64_TLBI_RVALE1ISNXS = 89;
	public static final int ARM64_TLBI_RVALE1NXS = 90;
	public static final int ARM64_TLBI_RVALE1OS = 91;
	public static final int ARM64_TLBI_RVALE1OSNXS = 92;
	public static final int ARM64_TLBI_RVALE2 = 93;
	public static final int ARM64_TLBI_RVALE2IS = 94;
	public static final int ARM64_TLBI_RVALE2ISNXS = 95;
	public static final int ARM64_TLBI_RVALE2NXS = 96;
	public static final int ARM64_TLBI_RVALE2OS = 97;
	public static final int ARM64_TLBI_RVALE2OSNXS = 98;
	public static final int ARM64_TLBI_RVALE3 = 99;
	public static final int ARM64_TLBI_RVALE3IS = 100;
	public static final int ARM64_TLBI_RVALE3ISNXS = 101;
	public static final int ARM64_TLBI_RVALE3NXS = 102;
	public static final int ARM64_TLBI_RVALE3OS = 103;
	public static final int ARM64_TLBI_RVALE3OSNXS = 104;
	public static final int ARM64_TLBI_VAAE1 = 105;
	public static final int ARM64_TLBI_VAAE1IS = 106;
	public static final int ARM64_TLBI_VAAE1ISNXS = 107;
	public static final int ARM64_TLBI_VAAE1NXS = 108;
	public static final int ARM64_TLBI_VAAE1OS = 109;
	public static final int ARM64_TLBI_VAAE1OSNXS = 110;
	public static final int ARM64_TLBI_VAALE1 = 111;
	public static final int ARM64_TLBI_VAALE1IS = 112;
	public static final int ARM64_TLBI_VAALE1ISNXS = 113;
	public static final int ARM64_TLBI_VAALE1NXS = 114;
	public static final int ARM64_TLBI_VAALE1OS = 115;
	public static final int ARM64_TLBI_VAALE1OSNXS = 116;
	public static final int ARM64_TLBI_VAE1 = 117;
	public static final int ARM64_TLBI_VAE1IS = 118;
	public static final int ARM64_TLBI_VAE1ISNXS = 119;
	public static final int ARM64_TLBI_VAE1NXS = 120;
	public static final int ARM64_TLBI_VAE1OS = 121;
	public static final int ARM64_TLBI_VAE1OSNXS = 122;
	public static final int ARM64_TLBI_VAE2 = 123;
	public static final int ARM64_TLBI_VAE2IS = 124;
	public static final int ARM64_TLBI_VAE2ISNXS = 125;
	public static final int ARM64_TLBI_VAE2NXS = 126;
	public static final int ARM64_TLBI_VAE2OS = 127;
	public static final int ARM64_TLBI_VAE2OSNXS = 128;
	public static final int ARM64_TLBI_VAE3 = 129;
	public static final int ARM64_TLBI_VAE3IS = 130;
	public static final int ARM64_TLBI_VAE3ISNXS = 131;
	public static final int ARM64_TLBI_VAE3NXS = 132;
	public static final int ARM64_TLBI_VAE3OS = 133;
	public static final int ARM64_TLBI_VAE3OSNXS = 134;
	public static final int ARM64_TLBI_VALE1 = 135;
	public static final int ARM64_TLBI_VALE1IS = 136;
	public static final int ARM64_TLBI_VALE1ISNXS = 137;
	public static final int ARM64_TLBI_VALE1NXS = 138;
	public static final int ARM64_TLBI_VALE1OS = 139;
	public static final int ARM64_TLBI_VALE1OSNXS = 140;
	public static final int ARM64_TLBI_VALE2 = 141;
	public static final int ARM64_TLBI_VALE2IS = 142;
	public static final int ARM64_TLBI_VALE2ISNXS = 143;
	public static final int ARM64_TLBI_VALE2NXS = 144;
	public static final int ARM64_TLBI_VALE2OS = 145;
	public static final int ARM64_TLBI_VALE2OSNXS = 146;
	public static final int ARM64_TLBI_VALE3 = 147;
	public static final int ARM64_TLBI_VALE3IS = 148;
	public static final int ARM64_TLBI_VALE3ISNXS = 149;
	public static final int ARM64_TLBI_VALE3NXS = 150;
	public static final int ARM64_TLBI_VALE3OS = 151;
	public static final int ARM64_TLBI_VALE3OSNXS = 152;
	public static final int ARM64_TLBI_VMALLE1 = 153;
	public static final int ARM64_TLBI_VMALLE1IS = 154;
	public static final int ARM64_TLBI_VMALLE1ISNXS = 155;
	public static final int ARM64_TLBI_VMALLE1NXS = 156;
	public static final int ARM64_TLBI_VMALLE1OS = 157;
	public static final int ARM64_TLBI_VMALLE1OSNXS = 158;
	public static final int ARM64_TLBI_VMALLS12E1 = 159;
	public static final int ARM64_TLBI_VMALLS12E1IS = 160;
	public static final int ARM64_TLBI_VMALLS12E1ISNXS = 161;
	public static final int ARM64_TLBI_VMALLS12E1NXS = 162;
	public static final int ARM64_TLBI_VMALLS12E1OS = 163;
	public static final int ARM64_TLBI_VMALLS12E1OSNXS = 164;
	public static final int ARM64_AT_S1E1R = 165;
	public static final int ARM64_AT_S1E2R = 166;
	public static final int ARM64_AT_S1E3R = 167;
	public static final int ARM64_AT_S1E1W = 168;
	public static final int ARM64_AT_S1E2W = 169;
	public static final int ARM64_AT_S1E3W = 170;
	public static final int ARM64_AT_S1E0R = 171;
	public static final int ARM64_AT_S1E0W = 172;
	public static final int ARM64_AT_S12E1R = 173;
	public static final int ARM64_AT_S12E1W = 174;
	public static final int ARM64_AT_S12E0R = 175;
	public static final int ARM64_AT_S12E0W = 176;
	public static final int ARM64_AT_S1E1RP = 177;
	public static final int ARM64_AT_S1E1WP = 178;
	public static final int ARM64_DC_CGDSW = 179;
	public static final int ARM64_DC_CGDVAC = 180;
	public static final int ARM64_DC_CGDVADP = 181;
	public static final int ARM64_DC_CGDVAP = 182;
	public static final int ARM64_DC_CGSW = 183;
	public static final int ARM64_DC_CGVAC = 184;
	public static final int ARM64_DC_CGVADP = 185;
	public static final int ARM64_DC_CGVAP = 186;
	public static final int ARM64_DC_CIGDSW = 187;
	public static final int ARM64_DC_CIGDVAC = 188;
	public static final int ARM64_DC_CIGSW = 189;
	public static final int ARM64_DC_CIGVAC = 190;
	public static final int ARM64_DC_CISW = 191;
	public static final int ARM64_DC_CIVAC = 192;
	public static final int ARM64_DC_CSW = 193;
	public static final int ARM64_DC_CVAC = 194;
	public static final int ARM64_DC_CVADP = 195;
	public static final int ARM64_DC_CVAP = 196;
	public static final int ARM64_DC_CVAU = 197;
	public static final int ARM64_DC_GVA = 198;
	public static final int ARM64_DC_GZVA = 199;
	public static final int ARM64_DC_IGDSW = 200;
	public static final int ARM64_DC_IGDVAC = 201;
	public static final int ARM64_DC_IGSW = 202;
	public static final int ARM64_DC_IGVAC = 203;
	public static final int ARM64_DC_ISW = 204;
	public static final int ARM64_DC_IVAC = 205;
	public static final int ARM64_DC_ZVA = 206;
	public static final int ARM64_IC_IALLUIS = 207;
	public static final int ARM64_IC_IALLU = 208;
	public static final int ARM64_IC_IVAU = 209;

	public static final int ARM64_SVCR_INVALID = 0;
	public static final int ARM64_SVCR_SVCRSM = 0x1;
	public static final int ARM64_SVCR_SVCRSMZA = 0x3;
	public static final int ARM64_SVCR_SVCRZA = 0x2;

	public static final int ARM64_PRFM_INVALID = 0;
	public static final int ARM64_PRFM_PLDL1KEEP = 0x00+1;
	public static final int ARM64_PRFM_PLDL1STRM = 0x01+1;
	public static final int ARM64_PRFM_PLDL2KEEP = 0x02+1;
	public static final int ARM64_PRFM_PLDL2STRM = 0x03+1;
	public static final int ARM64_PRFM_PLDL3KEEP = 0x04+1;
	public static final int ARM64_PRFM_PLDL3STRM = 0x05+1;
	public static final int ARM64_PRFM_PLIL1KEEP = 0x08+1;
	public static final int ARM64_PRFM_PLIL1STRM = 0x09+1;
	public static final int ARM64_PRFM_PLIL2KEEP = 0x0a+1;
	public static final int ARM64_PRFM_PLIL2STRM = 0x0b+1;
	public static final int ARM64_PRFM_PLIL3KEEP = 0x0c+1;
	public static final int ARM64_PRFM_PLIL3STRM = 0x0d+1;
	public static final int ARM64_PRFM_PSTL1KEEP = 0x10+1;
	public static final int ARM64_PRFM_PSTL1STRM = 0x11+1;
	public static final int ARM64_PRFM_PSTL2KEEP = 0x12+1;
	public static final int ARM64_PRFM_PSTL2STRM = 0x13+1;
	public static final int ARM64_PRFM_PSTL3KEEP = 0x14+1;
	public static final int ARM64_PRFM_PSTL3STRM = 0x15+1;

	public static final int ARM64_REG_INVALID = 0;
	public static final int ARM64_REG_FFR = 1;
	public static final int ARM64_REG_FP = 2;
	public static final int ARM64_REG_LR = 3;
	public static final int ARM64_REG_NZCV = 4;
	public static final int ARM64_REG_SP = 5;
	public static final int ARM64_REG_VG = 6;
	public static final int ARM64_REG_WSP = 7;
	public static final int ARM64_REG_WZR = 8;
	public static final int ARM64_REG_XZR = 9;
	public static final int ARM64_REG_ZA = 10;
	public static final int ARM64_REG_B0 = 11;
	public static final int ARM64_REG_B1 = 12;
	public static final int ARM64_REG_B2 = 13;
	public static final int ARM64_REG_B3 = 14;
	public static final int ARM64_REG_B4 = 15;
	public static final int ARM64_REG_B5 = 16;
	public static final int ARM64_REG_B6 = 17;
	public static final int ARM64_REG_B7 = 18;
	public static final int ARM64_REG_B8 = 19;
	public static final int ARM64_REG_B9 = 20;
	public static final int ARM64_REG_B10 = 21;
	public static final int ARM64_REG_B11 = 22;
	public static final int ARM64_REG_B12 = 23;
	public static final int ARM64_REG_B13 = 24;
	public static final int ARM64_REG_B14 = 25;
	public static final int ARM64_REG_B15 = 26;
	public static final int ARM64_REG_B16 = 27;
	public static final int ARM64_REG_B17 = 28;
	public static final int ARM64_REG_B18 = 29;
	public static final int ARM64_REG_B19 = 30;
	public static final int ARM64_REG_B20 = 31;
	public static final int ARM64_REG_B21 = 32;
	public static final int ARM64_REG_B22 = 33;
	public static final int ARM64_REG_B23 = 34;
	public static final int ARM64_REG_B24 = 35;
	public static final int ARM64_REG_B25 = 36;
	public static final int ARM64_REG_B26 = 37;
	public static final int ARM64_REG_B27 = 38;
	public static final int ARM64_REG_B28 = 39;
	public static final int ARM64_REG_B29 = 40;
	public static final int ARM64_REG_B30 = 41;
	public static final int ARM64_REG_B31 = 42;
	public static final int ARM64_REG_D0 = 43;
	public static final int ARM64_REG_D1 = 44;
	public static final int ARM64_REG_D2 = 45;
	public static final int ARM64_REG_D3 = 46;
	public static final int ARM64_REG_D4 = 47;
	public static final int ARM64_REG_D5 = 48;
	public static final int ARM64_REG_D6 = 49;
	public static final int ARM64_REG_D7 = 50;
	public static final int ARM64_REG_D8 = 51;
	public static final int ARM64_REG_D9 = 52;
	public static final int ARM64_REG_D10 = 53;
	public static final int ARM64_REG_D11 = 54;
	public static final int ARM64_REG_D12 = 55;
	public static final int ARM64_REG_D13 = 56;
	public static final int ARM64_REG_D14 = 57;
	public static final int ARM64_REG_D15 = 58;
	public static final int ARM64_REG_D16 = 59;
	public static final int ARM64_REG_D17 = 60;
	public static final int ARM64_REG_D18 = 61;
	public static final int ARM64_REG_D19 = 62;
	public static final int ARM64_REG_D20 = 63;
	public static final int ARM64_REG_D21 = 64;
	public static final int ARM64_REG_D22 = 65;
	public static final int ARM64_REG_D23 = 66;
	public static final int ARM64_REG_D24 = 67;
	public static final int ARM64_REG_D25 = 68;
	public static final int ARM64_REG_D26 = 69;
	public static final int ARM64_REG_D27 = 70;
	public static final int ARM64_REG_D28 = 71;
	public static final int ARM64_REG_D29 = 72;
	public static final int ARM64_REG_D30 = 73;
	public static final int ARM64_REG_D31 = 74;
	public static final int ARM64_REG_H0 = 75;
	public static final int ARM64_REG_H1 = 76;
	public static final int ARM64_REG_H2 = 77;
	public static final int ARM64_REG_H3 = 78;
	public static final int ARM64_REG_H4 = 79;
	public static final int ARM64_REG_H5 = 80;
	public static final int ARM64_REG_H6 = 81;
	public static final int ARM64_REG_H7 = 82;
	public static final int ARM64_REG_H8 = 83;
	public static final int ARM64_REG_H9 = 84;
	public static final int ARM64_REG_H10 = 85;
	public static final int ARM64_REG_H11 = 86;
	public static final int ARM64_REG_H12 = 87;
	public static final int ARM64_REG_H13 = 88;
	public static final int ARM64_REG_H14 = 89;
	public static final int ARM64_REG_H15 = 90;
	public static final int ARM64_REG_H16 = 91;
	public static final int ARM64_REG_H17 = 92;
	public static final int ARM64_REG_H18 = 93;
	public static final int ARM64_REG_H19 = 94;
	public static final int ARM64_REG_H20 = 95;
	public static final int ARM64_REG_H21 = 96;
	public static final int ARM64_REG_H22 = 97;
	public static final int ARM64_REG_H23 = 98;
	public static final int ARM64_REG_H24 = 99;
	public static final int ARM64_REG_H25 = 100;
	public static final int ARM64_REG_H26 = 101;
	public static final int ARM64_REG_H27 = 102;
	public static final int ARM64_REG_H28 = 103;
	public static final int ARM64_REG_H29 = 104;
	public static final int ARM64_REG_H30 = 105;
	public static final int ARM64_REG_H31 = 106;
	public static final int ARM64_REG_P0 = 107;
	public static final int ARM64_REG_P1 = 108;
	public static final int ARM64_REG_P2 = 109;
	public static final int ARM64_REG_P3 = 110;
	public static final int ARM64_REG_P4 = 111;
	public static final int ARM64_REG_P5 = 112;
	public static final int ARM64_REG_P6 = 113;
	public static final int ARM64_REG_P7 = 114;
	public static final int ARM64_REG_P8 = 115;
	public static final int ARM64_REG_P9 = 116;
	public static final int ARM64_REG_P10 = 117;
	public static final int ARM64_REG_P11 = 118;
	public static final int ARM64_REG_P12 = 119;
	public static final int ARM64_REG_P13 = 120;
	public static final int ARM64_REG_P14 = 121;
	public static final int ARM64_REG_P15 = 122;
	public static final int ARM64_REG_Q0 = 123;
	public static final int ARM64_REG_Q1 = 124;
	public static final int ARM64_REG_Q2 = 125;
	public static final int ARM64_REG_Q3 = 126;
	public static final int ARM64_REG_Q4 = 127;
	public static final int ARM64_REG_Q5 = 128;
	public static final int ARM64_REG_Q6 = 129;
	public static final int ARM64_REG_Q7 = 130;
	public static final int ARM64_REG_Q8 = 131;
	public static final int ARM64_REG_Q9 = 132;
	public static final int ARM64_REG_Q10 = 133;
	public static final int ARM64_REG_Q11 = 134;
	public static final int ARM64_REG_Q12 = 135;
	public static final int ARM64_REG_Q13 = 136;
	public static final int ARM64_REG_Q14 = 137;
	public static final int ARM64_REG_Q15 = 138;
	public static final int ARM64_REG_Q16 = 139;
	public static final int ARM64_REG_Q17 = 140;
	public static final int ARM64_REG_Q18 = 141;
	public static final int ARM64_REG_Q19 = 142;
	public static final int ARM64_REG_Q20 = 143;
	public static final int ARM64_REG_Q21 = 144;
	public static final int ARM64_REG_Q22 = 145;
	public static final int ARM64_REG_Q23 = 146;
	public static final int ARM64_REG_Q24 = 147;
	public static final int ARM64_REG_Q25 = 148;
	public static final int ARM64_REG_Q26 = 149;
	public static final int ARM64_REG_Q27 = 150;
	public static final int ARM64_REG_Q28 = 151;
	public static final int ARM64_REG_Q29 = 152;
	public static final int ARM64_REG_Q30 = 153;
	public static final int ARM64_REG_Q31 = 154;
	public static final int ARM64_REG_S0 = 155;
	public static final int ARM64_REG_S1 = 156;
	public static final int ARM64_REG_S2 = 157;
	public static final int ARM64_REG_S3 = 158;
	public static final int ARM64_REG_S4 = 159;
	public static final int ARM64_REG_S5 = 160;
	public static final int ARM64_REG_S6 = 161;
	public static final int ARM64_REG_S7 = 162;
	public static final int ARM64_REG_S8 = 163;
	public static final int ARM64_REG_S9 = 164;
	public static final int ARM64_REG_S10 = 165;
	public static final int ARM64_REG_S11 = 166;
	public static final int ARM64_REG_S12 = 167;
	public static final int ARM64_REG_S13 = 168;
	public static final int ARM64_REG_S14 = 169;
	public static final int ARM64_REG_S15 = 170;
	public static final int ARM64_REG_S16 = 171;
	public static final int ARM64_REG_S17 = 172;
	public static final int ARM64_REG_S18 = 173;
	public static final int ARM64_REG_S19 = 174;
	public static final int ARM64_REG_S20 = 175;
	public static final int ARM64_REG_S21 = 176;
	public static final int ARM64_REG_S22 = 177;
	public static final int ARM64_REG_S23 = 178;
	public static final int ARM64_REG_S24 = 179;
	public static final int ARM64_REG_S25 = 180;
	public static final int ARM64_REG_S26 = 181;
	public static final int ARM64_REG_S27 = 182;
	public static final int ARM64_REG_S28 = 183;
	public static final int ARM64_REG_S29 = 184;
	public static final int ARM64_REG_S30 = 185;
	public static final int ARM64_REG_S31 = 186;
	public static final int ARM64_REG_W0 = 187;
	public static final int ARM64_REG_W1 = 188;
	public static final int ARM64_REG_W2 = 189;
	public static final int ARM64_REG_W3 = 190;
	public static final int ARM64_REG_W4 = 191;
	public static final int ARM64_REG_W5 = 192;
	public static final int ARM64_REG_W6 = 193;
	public static final int ARM64_REG_W7 = 194;
	public static final int ARM64_REG_W8 = 195;
	public static final int ARM64_REG_W9 = 196;
	public static final int ARM64_REG_W10 = 197;
	public static final int ARM64_REG_W11 = 198;
	public static final int ARM64_REG_W12 = 199;
	public static final int ARM64_REG_W13 = 200;
	public static final int ARM64_REG_W14 = 201;
	public static final int ARM64_REG_W15 = 202;
	public static final int ARM64_REG_W16 = 203;
	public static final int ARM64_REG_W17 = 204;
	public static final int ARM64_REG_W18 = 205;
	public static final int ARM64_REG_W19 = 206;
	public static final int ARM64_REG_W20 = 207;
	public static final int ARM64_REG_W21 = 208;
	public static final int ARM64_REG_W22 = 209;
	public static final int ARM64_REG_W23 = 210;
	public static final int ARM64_REG_W24 = 211;
	public static final int ARM64_REG_W25 = 212;
	public static final int ARM64_REG_W26 = 213;
	public static final int ARM64_REG_W27 = 214;
	public static final int ARM64_REG_W28 = 215;
	public static final int ARM64_REG_W29 = 216;
	public static final int ARM64_REG_W30 = 217;
	public static final int ARM64_REG_X0 = 218;
	public static final int ARM64_REG_X1 = 219;
	public static final int ARM64_REG_X2 = 220;
	public static final int ARM64_REG_X3 = 221;
	public static final int ARM64_REG_X4 = 222;
	public static final int ARM64_REG_X5 = 223;
	public static final int ARM64_REG_X6 = 224;
	public static final int ARM64_REG_X7 = 225;
	public static final int ARM64_REG_X8 = 226;
	public static final int ARM64_REG_X9 = 227;
	public static final int ARM64_REG_X10 = 228;
	public static final int ARM64_REG_X11 = 229;
	public static final int ARM64_REG_X12 = 230;
	public static final int ARM64_REG_X13 = 231;
	public static final int ARM64_REG_X14 = 232;
	public static final int ARM64_REG_X15 = 233;
	public static final int ARM64_REG_X16 = 234;
	public static final int ARM64_REG_X17 = 235;
	public static final int ARM64_REG_X18 = 236;
	public static final int ARM64_REG_X19 = 237;
	public static final int ARM64_REG_X20 = 238;
	public static final int ARM64_REG_X21 = 239;
	public static final int ARM64_REG_X22 = 240;
	public static final int ARM64_REG_X23 = 241;
	public static final int ARM64_REG_X24 = 242;
	public static final int ARM64_REG_X25 = 243;
	public static final int ARM64_REG_X26 = 244;
	public static final int ARM64_REG_X27 = 245;
	public static final int ARM64_REG_X28 = 246;
	public static final int ARM64_REG_Z0 = 247;
	public static final int ARM64_REG_Z1 = 248;
	public static final int ARM64_REG_Z2 = 249;
	public static final int ARM64_REG_Z3 = 250;
	public static final int ARM64_REG_Z4 = 251;
	public static final int ARM64_REG_Z5 = 252;
	public static final int ARM64_REG_Z6 = 253;
	public static final int ARM64_REG_Z7 = 254;
	public static final int ARM64_REG_Z8 = 255;
	public static final int ARM64_REG_Z9 = 256;
	public static final int ARM64_REG_Z10 = 257;
	public static final int ARM64_REG_Z11 = 258;
	public static final int ARM64_REG_Z12 = 259;
	public static final int ARM64_REG_Z13 = 260;
	public static final int ARM64_REG_Z14 = 261;
	public static final int ARM64_REG_Z15 = 262;
	public static final int ARM64_REG_Z16 = 263;
	public static final int ARM64_REG_Z17 = 264;
	public static final int ARM64_REG_Z18 = 265;
	public static final int ARM64_REG_Z19 = 266;
	public static final int ARM64_REG_Z20 = 267;
	public static final int ARM64_REG_Z21 = 268;
	public static final int ARM64_REG_Z22 = 269;
	public static final int ARM64_REG_Z23 = 270;
	public static final int ARM64_REG_Z24 = 271;
	public static final int ARM64_REG_Z25 = 272;
	public static final int ARM64_REG_Z26 = 273;
	public static final int ARM64_REG_Z27 = 274;
	public static final int ARM64_REG_Z28 = 275;
	public static final int ARM64_REG_Z29 = 276;
	public static final int ARM64_REG_Z30 = 277;
	public static final int ARM64_REG_Z31 = 278;
	public static final int ARM64_REG_ZAB0 = 279;
	public static final int ARM64_REG_ZAD0 = 280;
	public static final int ARM64_REG_ZAD1 = 281;
	public static final int ARM64_REG_ZAD2 = 282;
	public static final int ARM64_REG_ZAD3 = 283;
	public static final int ARM64_REG_ZAD4 = 284;
	public static final int ARM64_REG_ZAD5 = 285;
	public static final int ARM64_REG_ZAD6 = 286;
	public static final int ARM64_REG_ZAD7 = 287;
	public static final int ARM64_REG_ZAH0 = 288;
	public static final int ARM64_REG_ZAH1 = 289;
	public static final int ARM64_REG_ZAQ0 = 290;
	public static final int ARM64_REG_ZAQ1 = 291;
	public static final int ARM64_REG_ZAQ2 = 292;
	public static final int ARM64_REG_ZAQ3 = 293;
	public static final int ARM64_REG_ZAQ4 = 294;
	public static final int ARM64_REG_ZAQ5 = 295;
	public static final int ARM64_REG_ZAQ6 = 296;
	public static final int ARM64_REG_ZAQ7 = 297;
	public static final int ARM64_REG_ZAQ8 = 298;
	public static final int ARM64_REG_ZAQ9 = 299;
	public static final int ARM64_REG_ZAQ10 = 300;
	public static final int ARM64_REG_ZAQ11 = 301;
	public static final int ARM64_REG_ZAQ12 = 302;
	public static final int ARM64_REG_ZAQ13 = 303;
	public static final int ARM64_REG_ZAQ14 = 304;
	public static final int ARM64_REG_ZAQ15 = 305;
	public static final int ARM64_REG_ZAS0 = 306;
	public static final int ARM64_REG_ZAS1 = 307;
	public static final int ARM64_REG_ZAS2 = 308;
	public static final int ARM64_REG_ZAS3 = 309;
	public static final int ARM64_REG_V0 = 310;
	public static final int ARM64_REG_V1 = 311;
	public static final int ARM64_REG_V2 = 312;
	public static final int ARM64_REG_V3 = 313;
	public static final int ARM64_REG_V4 = 314;
	public static final int ARM64_REG_V5 = 315;
	public static final int ARM64_REG_V6 = 316;
	public static final int ARM64_REG_V7 = 317;
	public static final int ARM64_REG_V8 = 318;
	public static final int ARM64_REG_V9 = 319;
	public static final int ARM64_REG_V10 = 320;
	public static final int ARM64_REG_V11 = 321;
	public static final int ARM64_REG_V12 = 322;
	public static final int ARM64_REG_V13 = 323;
	public static final int ARM64_REG_V14 = 324;
	public static final int ARM64_REG_V15 = 325;
	public static final int ARM64_REG_V16 = 326;
	public static final int ARM64_REG_V17 = 327;
	public static final int ARM64_REG_V18 = 328;
	public static final int ARM64_REG_V19 = 329;
	public static final int ARM64_REG_V20 = 330;
	public static final int ARM64_REG_V21 = 331;
	public static final int ARM64_REG_V22 = 332;
	public static final int ARM64_REG_V23 = 333;
	public static final int ARM64_REG_V24 = 334;
	public static final int ARM64_REG_V25 = 335;
	public static final int ARM64_REG_V26 = 336;
	public static final int ARM64_REG_V27 = 337;
	public static final int ARM64_REG_V28 = 338;
	public static final int ARM64_REG_V29 = 339;
	public static final int ARM64_REG_V30 = 340;
	public static final int ARM64_REG_V31 = 341;
	public static final int ARM64_REG_ENDING = 342;
	public static final int ARM64_REG_IP0 = ARM64_REG_X16;
	public static final int ARM64_REG_IP1 = ARM64_REG_X17;
	public static final int ARM64_REG_X29 = ARM64_REG_FP;
	public static final int ARM64_REG_X30 = ARM64_REG_LR;

	public static final int ARM64_INS_INVALID = 0;
	public static final int ARM64_INS_ABS = 1;
	public static final int ARM64_INS_ADC = 2;
	public static final int ARM64_INS_ADCLB = 3;
	public static final int ARM64_INS_ADCLT = 4;
	public static final int ARM64_INS_ADCS = 5;
	public static final int ARM64_INS_ADD = 6;
	public static final int ARM64_INS_ADDG = 7;
	public static final int ARM64_INS_ADDHA = 8;
	public static final int ARM64_INS_ADDHN = 9;
	public static final int ARM64_INS_ADDHN2 = 10;
	public static final int ARM64_INS_ADDHNB = 11;
	public static final int ARM64_INS_ADDHNT = 12;
	public static final int ARM64_INS_ADDP = 13;
	public static final int ARM64_INS_ADDPL = 14;
	public static final int ARM64_INS_ADDS = 15;
	public static final int ARM64_INS_ADDV = 16;
	public static final int ARM64_INS_ADDVA = 17;
	public static final int ARM64_INS_ADDVL = 18;
	public static final int ARM64_INS_ADR = 19;
	public static final int ARM64_INS_ADRP = 20;
	public static final int ARM64_INS_AESD = 21;
	public static final int ARM64_INS_AESE = 22;
	public static final int ARM64_INS_AESIMC = 23;
	public static final int ARM64_INS_AESMC = 24;
	public static final int ARM64_INS_AND = 25;
	public static final int ARM64_INS_ANDS = 26;
	public static final int ARM64_INS_ANDV = 27;
	public static final int ARM64_INS_ASR = 28;
	public static final int ARM64_INS_ASRD = 29;
	public static final int ARM64_INS_ASRR = 30;
	public static final int ARM64_INS_ASRV = 31;
	public static final int ARM64_INS_AUTDA = 32;
	public static final int ARM64_INS_AUTDB = 33;
	public static final int ARM64_INS_AUTDZA = 34;
	public static final int ARM64_INS_AUTDZB = 35;
	public static final int ARM64_INS_AUTIA = 36;
	public static final int ARM64_INS_AUTIA1716 = 37;
	public static final int ARM64_INS_AUTIASP = 38;
	public static final int ARM64_INS_AUTIAZ = 39;
	public static final int ARM64_INS_AUTIB = 40;
	public static final int ARM64_INS_AUTIB1716 = 41;
	public static final int ARM64_INS_AUTIBSP = 42;
	public static final int ARM64_INS_AUTIBZ = 43;
	public static final int ARM64_INS_AUTIZA = 44;
	public static final int ARM64_INS_AUTIZB = 45;
	public static final int ARM64_INS_AXFLAG = 46;
	public static final int ARM64_INS_B = 47;
	public static final int ARM64_INS_BC = 48;
	public static final int ARM64_INS_BCAX = 49;
	public static final int ARM64_INS_BDEP = 50;
	public static final int ARM64_INS_BEXT = 51;
	public static final int ARM64_INS_BFCVT = 52;
	public static final int ARM64_INS_BFCVTN = 53;
	public static final int ARM64_INS_BFCVTN2 = 54;
	public static final int ARM64_INS_BFCVTNT = 55;
	public static final int ARM64_INS_BFDOT = 56;
	public static final int ARM64_INS_BFM = 57;
	public static final int ARM64_INS_BFMLALB = 58;
	public static final int ARM64_INS_BFMLALT = 59;
	public static final int ARM64_INS_BFMMLA = 60;
	public static final int ARM64_INS_BFMOPA = 61;
	public static final int ARM64_INS_BFMOPS = 62;
	public static final int ARM64_INS_BGRP = 63;
	public static final int ARM64_INS_BIC = 64;
	public static final int ARM64_INS_BICS = 65;
	public static final int ARM64_INS_BIF = 66;
	public static final int ARM64_INS_BIT = 67;
	public static final int ARM64_INS_BL = 68;
	public static final int ARM64_INS_BLR = 69;
	public static final int ARM64_INS_BLRAA = 70;
	public static final int ARM64_INS_BLRAAZ = 71;
	public static final int ARM64_INS_BLRAB = 72;
	public static final int ARM64_INS_BLRABZ = 73;
	public static final int ARM64_INS_BR = 74;
	public static final int ARM64_INS_BRAA = 75;
	public static final int ARM64_INS_BRAAZ = 76;
	public static final int ARM64_INS_BRAB = 77;
	public static final int ARM64_INS_BRABZ = 78;
	public static final int ARM64_INS_BRB = 79;
	public static final int ARM64_INS_BRK = 80;
	public static final int ARM64_INS_BRKA = 81;
	public static final int ARM64_INS_BRKAS = 82;
	public static final int ARM64_INS_BRKB = 83;
	public static final int ARM64_INS_BRKBS = 84;
	public static final int ARM64_INS_BRKN = 85;
	public static final int ARM64_INS_BRKNS = 86;
	public static final int ARM64_INS_BRKPA = 87;
	public static final int ARM64_INS_BRKPAS = 88;
	public static final int ARM64_INS_BRKPB = 89;
	public static final int ARM64_INS_BRKPBS = 90;
	public static final int ARM64_INS_BSL = 91;
	public static final int ARM64_INS_BSL1N = 92;
	public static final int ARM64_INS_BSL2N = 93;
	public static final int ARM64_INS_BTI = 94;
	public static final int ARM64_INS_CADD = 95;
	public static final int ARM64_INS_CAS = 96;
	public static final int ARM64_INS_CASA = 97;
	public static final int ARM64_INS_CASAB = 98;
	public static final int ARM64_INS_CASAH = 99;
	public static final int ARM64_INS_CASAL = 100;
	public static final int ARM64_INS_CASALB = 101;
	public static final int ARM64_INS_CASALH = 102;
	public static final int ARM64_INS_CASB = 103;
	public static final int ARM64_INS_CASH = 104;
	public static final int ARM64_INS_CASL = 105;
	public static final int ARM64_INS_CASLB = 106;
	public static final int ARM64_INS_CASLH = 107;
	public static final int ARM64_INS_CASP = 108;
	public static final int ARM64_INS_CASPA = 109;
	public static final int ARM64_INS_CASPAL = 110;
	public static final int ARM64_INS_CASPL = 111;
	public static final int ARM64_INS_CBNZ = 112;
	public static final int ARM64_INS_CBZ = 113;
	public static final int ARM64_INS_CCMN = 114;
	public static final int ARM64_INS_CCMP = 115;
	public static final int ARM64_INS_CDOT = 116;
	public static final int ARM64_INS_CFINV = 117;
	public static final int ARM64_INS_CINC = 118;
	public static final int ARM64_INS_CINV = 119;
	public static final int ARM64_INS_CLASTA = 120;
	public static final int ARM64_INS_CLASTB = 121;
	public static final int ARM64_INS_CLREX = 122;
	public static final int ARM64_INS_CLS = 123;
	public static final int ARM64_INS_CLZ = 124;
	public static final int ARM64_INS_CMEQ = 125;
	public static final int ARM64_INS_CMGE = 126;
	public static final int ARM64_INS_CMGT = 127;
	public static final int ARM64_INS_CMHI = 128;
	public static final int ARM64_INS_CMHS = 129;
	public static final int ARM64_INS_CMLA = 130;
	public static final int ARM64_INS_CMLE = 131;
	public static final int ARM64_INS_CMLO = 132;
	public static final int ARM64_INS_CMLS = 133;
	public static final int ARM64_INS_CMLT = 134;
	public static final int ARM64_INS_CMN = 135;
	public static final int ARM64_INS_CMP = 136;
	public static final int ARM64_INS_CMPEQ = 137;
	public static final int ARM64_INS_CMPGE = 138;
	public static final int ARM64_INS_CMPGT = 139;
	public static final int ARM64_INS_CMPHI = 140;
	public static final int ARM64_INS_CMPHS = 141;
	public static final int ARM64_INS_CMPLE = 142;
	public static final int ARM64_INS_CMPLO = 143;
	public static final int ARM64_INS_CMPLS = 144;
	public static final int ARM64_INS_CMPLT = 145;
	public static final int ARM64_INS_CMPNE = 146;
	public static final int ARM64_INS_CMPP = 147;
	public static final int ARM64_INS_CMTST = 148;
	public static final int ARM64_INS_CNEG = 149;
	public static final int ARM64_INS_CNOT = 150;
	public static final int ARM64_INS_CNT = 151;
	public static final int ARM64_INS_CNTB = 152;
	public static final int ARM64_INS_CNTD = 153;
	public static final int ARM64_INS_CNTH = 154;
	public static final int ARM64_INS_CNTP = 155;
	public static final int ARM64_INS_CNTW = 156;
	public static final int ARM64_INS_COMPACT = 157;
	public static final int ARM64_INS_CPY = 158;
	public static final int ARM64_INS_CPYE = 159;
	public static final int ARM64_INS_CPYEN = 160;
	public static final int ARM64_INS_CPYERN = 161;
	public static final int ARM64_INS_CPYERT = 162;
	public static final int ARM64_INS_CPYERTN = 163;
	public static final int ARM64_INS_CPYERTRN = 164;
	public static final int ARM64_INS_CPYERTWN = 165;
	public static final int ARM64_INS_CPYET = 166;
	public static final int ARM64_INS_CPYETN = 167;
	public static final int ARM64_INS_CPYETRN = 168;
	public static final int ARM64_INS_CPYETWN = 169;
	public static final int ARM64_INS_CPYEWN = 170;
	public static final int ARM64_INS_CPYEWT = 171;
	public static final int ARM64_INS_CPYEWTN = 172;
	public static final int ARM64_INS_CPYEWTRN = 173;
	public static final int ARM64_INS_CPYEWTWN = 174;
	public static final int ARM64_INS_CPYFE = 175;
	public static final int ARM64_INS_CPYFEN = 176;
	public static final int ARM64_INS_CPYFERN = 177;
	public static final int ARM64_INS_CPYFERT = 178;
	public static final int ARM64_INS_CPYFERTN = 179;
	public static final int ARM64_INS_CPYFERTRN = 180;
	public static final int ARM64_INS_CPYFERTWN = 181;
	public static final int ARM64_INS_CPYFET = 182;
	public static final int ARM64_INS_CPYFETN = 183;
	public static final int ARM64_INS_CPYFETRN = 184;
	public static final int ARM64_INS_CPYFETWN = 185;
	public static final int ARM64_INS_CPYFEWN = 186;
	public static final int ARM64_INS_CPYFEWT = 187;
	public static final int ARM64_INS_CPYFEWTN = 188;
	public static final int ARM64_INS_CPYFEWTRN = 189;
	public static final int ARM64_INS_CPYFEWTWN = 190;
	public static final int ARM64_INS_CPYFM = 191;
	public static final int ARM64_INS_CPYFMN = 192;
	public static final int ARM64_INS_CPYFMRN = 193;
	public static final int ARM64_INS_CPYFMRT = 194;
	public static final int ARM64_INS_CPYFMRTN = 195;
	public static final int ARM64_INS_CPYFMRTRN = 196;
	public static final int ARM64_INS_CPYFMRTWN = 197;
	public static final int ARM64_INS_CPYFMT = 198;
	public static final int ARM64_INS_CPYFMTN = 199;
	public static final int ARM64_INS_CPYFMTRN = 200;
	public static final int ARM64_INS_CPYFMTWN = 201;
	public static final int ARM64_INS_CPYFMWN = 202;
	public static final int ARM64_INS_CPYFMWT = 203;
	public static final int ARM64_INS_CPYFMWTN = 204;
	public static final int ARM64_INS_CPYFMWTRN = 205;
	public static final int ARM64_INS_CPYFMWTWN = 206;
	public static final int ARM64_INS_CPYFP = 207;
	public static final int ARM64_INS_CPYFPN = 208;
	public static final int ARM64_INS_CPYFPRN = 209;
	public static final int ARM64_INS_CPYFPRT = 210;
	public static final int ARM64_INS_CPYFPRTN = 211;
	public static final int ARM64_INS_CPYFPRTRN = 212;
	public static final int ARM64_INS_CPYFPRTWN = 213;
	public static final int ARM64_INS_CPYFPT = 214;
	public static final int ARM64_INS_CPYFPTN = 215;
	public static final int ARM64_INS_CPYFPTRN = 216;
	public static final int ARM64_INS_CPYFPTWN = 217;
	public static final int ARM64_INS_CPYFPWN = 218;
	public static final int ARM64_INS_CPYFPWT = 219;
	public static final int ARM64_INS_CPYFPWTN = 220;
	public static final int ARM64_INS_CPYFPWTRN = 221;
	public static final int ARM64_INS_CPYFPWTWN = 222;
	public static final int ARM64_INS_CPYM = 223;
	public static final int ARM64_INS_CPYMN = 224;
	public static final int ARM64_INS_CPYMRN = 225;
	public static final int ARM64_INS_CPYMRT = 226;
	public static final int ARM64_INS_CPYMRTN = 227;
	public static final int ARM64_INS_CPYMRTRN = 228;
	public static final int ARM64_INS_CPYMRTWN = 229;
	public static final int ARM64_INS_CPYMT = 230;
	public static final int ARM64_INS_CPYMTN = 231;
	public static final int ARM64_INS_CPYMTRN = 232;
	public static final int ARM64_INS_CPYMTWN = 233;
	public static final int ARM64_INS_CPYMWN = 234;
	public static final int ARM64_INS_CPYMWT = 235;
	public static final int ARM64_INS_CPYMWTN = 236;
	public static final int ARM64_INS_CPYMWTRN = 237;
	public static final int ARM64_INS_CPYMWTWN = 238;
	public static final int ARM64_INS_CPYP = 239;
	public static final int ARM64_INS_CPYPN = 240;
	public static final int ARM64_INS_CPYPRN = 241;
	public static final int ARM64_INS_CPYPRT = 242;
	public static final int ARM64_INS_CPYPRTN = 243;
	public static final int ARM64_INS_CPYPRTRN = 244;
	public static final int ARM64_INS_CPYPRTWN = 245;
	public static final int ARM64_INS_CPYPT = 246;
	public static final int ARM64_INS_CPYPTN = 247;
	public static final int ARM64_INS_CPYPTRN = 248;
	public static final int ARM64_INS_CPYPTWN = 249;
	public static final int ARM64_INS_CPYPWN = 250;
	public static final int ARM64_INS_CPYPWT = 251;
	public static final int ARM64_INS_CPYPWTN = 252;
	public static final int ARM64_INS_CPYPWTRN = 253;
	public static final int ARM64_INS_CPYPWTWN = 254;
	public static final int ARM64_INS_CRC32B = 255;
	public static final int ARM64_INS_CRC32CB = 256;
	public static final int ARM64_INS_CRC32CH = 257;
	public static final int ARM64_INS_CRC32CW = 258;
	public static final int ARM64_INS_CRC32CX = 259;
	public static final int ARM64_INS_CRC32H = 260;
	public static final int ARM64_INS_CRC32W = 261;
	public static final int ARM64_INS_CRC32X = 262;
	public static final int ARM64_INS_CSDB = 263;
	public static final int ARM64_INS_CSEL = 264;
	public static final int ARM64_INS_CSET = 265;
	public static final int ARM64_INS_CSETM = 266;
	public static final int ARM64_INS_CSINC = 267;
	public static final int ARM64_INS_CSINV = 268;
	public static final int ARM64_INS_CSNEG = 269;
	public static final int ARM64_INS_CTERMEQ = 270;
	public static final int ARM64_INS_CTERMNE = 271;
	public static final int ARM64_INS_DCPS1 = 272;
	public static final int ARM64_INS_DCPS2 = 273;
	public static final int ARM64_INS_DCPS3 = 274;
	public static final int ARM64_INS_DECB = 275;
	public static final int ARM64_INS_DECD = 276;
	public static final int ARM64_INS_DECH = 277;
	public static final int ARM64_INS_DECP = 278;
	public static final int ARM64_INS_DECW = 279;
	public static final int ARM64_INS_DFB = 280;
	public static final int ARM64_INS_DGH = 281;
	public static final int ARM64_INS_DMB = 282;
	public static final int ARM64_INS_DRPS = 283;
	public static final int ARM64_INS_DSB = 284;
	public static final int ARM64_INS_DUP = 285;
	public static final int ARM64_INS_DUPM = 286;
	public static final int ARM64_INS_EON = 287;
	public static final int ARM64_INS_EOR = 288;
	public static final int ARM64_INS_EOR3 = 289;
	public static final int ARM64_INS_EORBT = 290;
	public static final int ARM64_INS_EORS = 291;
	public static final int ARM64_INS_EORTB = 292;
	public static final int ARM64_INS_EORV = 293;
	public static final int ARM64_INS_ERET = 294;
	public static final int ARM64_INS_ERETAA = 295;
	public static final int ARM64_INS_ERETAB = 296;
	public static final int ARM64_INS_ESB = 297;
	public static final int ARM64_INS_EXT = 298;
	public static final int ARM64_INS_EXTR = 299;
	public static final int ARM64_INS_FABD = 300;
	public static final int ARM64_INS_FABS = 301;
	public static final int ARM64_INS_FACGE = 302;
	public static final int ARM64_INS_FACGT = 303;
	public static final int ARM64_INS_FACLE = 304;
	public static final int ARM64_INS_FACLT = 305;
	public static final int ARM64_INS_FADD = 306;
	public static final int ARM64_INS_FADDA = 307;
	public static final int ARM64_INS_FADDP = 308;
	public static final int ARM64_INS_FADDV = 309;
	public static final int ARM64_INS_FCADD = 310;
	public static final int ARM64_INS_FCCMP = 311;
	public static final int ARM64_INS_FCCMPE = 312;
	public static final int ARM64_INS_FCMEQ = 313;
	public static final int ARM64_INS_FCMGE = 314;
	public static final int ARM64_INS_FCMGT = 315;
	public static final int ARM64_INS_FCMLA = 316;
	public static final int ARM64_INS_FCMLE = 317;
	public static final int ARM64_INS_FCMLT = 318;
	public static final int ARM64_INS_FCMNE = 319;
	public static final int ARM64_INS_FCMP = 320;
	public static final int ARM64_INS_FCMPE = 321;
	public static final int ARM64_INS_FCMUO = 322;
	public static final int ARM64_INS_FCPY = 323;
	public static final int ARM64_INS_FCSEL = 324;
	public static final int ARM64_INS_FCVT = 325;
	public static final int ARM64_INS_FCVTAS = 326;
	public static final int ARM64_INS_FCVTAU = 327;
	public static final int ARM64_INS_FCVTL = 328;
	public static final int ARM64_INS_FCVTL2 = 329;
	public static final int ARM64_INS_FCVTLT = 330;
	public static final int ARM64_INS_FCVTMS = 331;
	public static final int ARM64_INS_FCVTMU = 332;
	public static final int ARM64_INS_FCVTN = 333;
	public static final int ARM64_INS_FCVTN2 = 334;
	public static final int ARM64_INS_FCVTNS = 335;
	public static final int ARM64_INS_FCVTNT = 336;
	public static final int ARM64_INS_FCVTNU = 337;
	public static final int ARM64_INS_FCVTPS = 338;
	public static final int ARM64_INS_FCVTPU = 339;
	public static final int ARM64_INS_FCVTX = 340;
	public static final int ARM64_INS_FCVTXN = 341;
	public static final int ARM64_INS_FCVTXN2 = 342;
	public static final int ARM64_INS_FCVTXNT = 343;
	public static final int ARM64_INS_FCVTZS = 344;
	public static final int ARM64_INS_FCVTZU = 345;
	public static final int ARM64_INS_FDIV = 346;
	public static final int ARM64_INS_FDIVR = 347;
	public static final int ARM64_INS_FDUP = 348;
	public static final int ARM64_INS_FEXPA = 349;
	public static final int ARM64_INS_FJCVTZS = 350;
	public static final int ARM64_INS_FLOGB = 351;
	public static final int ARM64_INS_FMAD = 352;
	public static final int ARM64_INS_FMADD = 353;
	public static final int ARM64_INS_FMAX = 354;
	public static final int ARM64_INS_FMAXNM = 355;
	public static final int ARM64_INS_FMAXNMP = 356;
	public static final int ARM64_INS_FMAXNMV = 357;
	public static final int ARM64_INS_FMAXP = 358;
	public static final int ARM64_INS_FMAXV = 359;
	public static final int ARM64_INS_FMIN = 360;
	public static final int ARM64_INS_FMINNM = 361;
	public static final int ARM64_INS_FMINNMP = 362;
	public static final int ARM64_INS_FMINNMV = 363;
	public static final int ARM64_INS_FMINP = 364;
	public static final int ARM64_INS_FMINV = 365;
	public static final int ARM64_INS_FMLA = 366;
	public static final int ARM64_INS_FMLAL = 367;
	public static final int ARM64_INS_FMLAL2 = 368;
	public static final int ARM64_INS_FMLALB = 369;
	public static final int ARM64_INS_FMLALT = 370;
	public static final int ARM64_INS_FMLS = 371;
	public static final int ARM64_INS_FMLSL = 372;
	public static final int ARM64_INS_FMLSL2 = 373;
	public static final int ARM64_INS_FMLSLB = 374;
	public static final int ARM64_INS_FMLSLT = 375;
	public static final int ARM64_INS_FMMLA = 376;
	public static final int ARM64_INS_FMOPA = 377;
	public static final int ARM64_INS_FMOPS = 378;
	public static final int ARM64_INS_FMOV = 379;
	public static final int ARM64_INS_FMSB = 380;
	public static final int ARM64_INS_FMSUB = 381;
	public static final int ARM64_INS_FMUL = 382;
	public static final int ARM64_INS_FMULX = 383;
	public static final int ARM64_INS_FNEG = 384;
	public static final int ARM64_INS_FNMAD = 385;
	public static final int ARM64_INS_FNMADD = 386;
	public static final int ARM64_INS_FNMLA = 387;
	public static final int ARM64_INS_FNMLS = 388;
	public static final int ARM64_INS_FNMSB = 389;
	public static final int ARM64_INS_FNMSUB = 390;
	public static final int ARM64_INS_FNMUL = 391;
	public static final int ARM64_INS_FRECPE = 392;
	public static final int ARM64_INS_FRECPS = 393;
	public static final int ARM64_INS_FRECPX = 394;
	public static final int ARM64_INS_FRINT32X = 395;
	public static final int ARM64_INS_FRINT32Z = 396;
	public static final int ARM64_INS_FRINT64X = 397;
	public static final int ARM64_INS_FRINT64Z = 398;
	public static final int ARM64_INS_FRINTA = 399;
	public static final int ARM64_INS_FRINTI = 400;
	public static final int ARM64_INS_FRINTM = 401;
	public static final int ARM64_INS_FRINTN = 402;
	public static final int ARM64_INS_FRINTP = 403;
	public static final int ARM64_INS_FRINTX = 404;
	public static final int ARM64_INS_FRINTZ = 405;
	public static final int ARM64_INS_FRSQRTE = 406;
	public static final int ARM64_INS_FRSQRTS = 407;
	public static final int ARM64_INS_FSCALE = 408;
	public static final int ARM64_INS_FSQRT = 409;
	public static final int ARM64_INS_FSUB = 410;
	public static final int ARM64_INS_FSUBR = 411;
	public static final int ARM64_INS_FTMAD = 412;
	public static final int ARM64_INS_FTSMUL = 413;
	public static final int ARM64_INS_FTSSEL = 414;
	public static final int ARM64_INS_GMI = 415;
	public static final int ARM64_INS_HINT = 416;
	public static final int ARM64_INS_HISTCNT = 417;
	public static final int ARM64_INS_HISTSEG = 418;
	public static final int ARM64_INS_HLT = 419;
	public static final int ARM64_INS_HVC = 420;
	public static final int ARM64_INS_INCB = 421;
	public static final int ARM64_INS_INCD = 422;
	public static final int ARM64_INS_INCH = 423;
	public static final int ARM64_INS_INCP = 424;
	public static final int ARM64_INS_INCW = 425;
	public static final int ARM64_INS_INDEX = 426;
	public static final int ARM64_INS_INS = 427;
	public static final int ARM64_INS_INSR = 428;
	public static final int ARM64_INS_IRG = 429;
	public static final int ARM64_INS_ISB = 430;
	public static final int ARM64_INS_LASTA = 431;
	public static final int ARM64_INS_LASTB = 432;
	public static final int ARM64_INS_LD1 = 433;
	public static final int ARM64_INS_LD1B = 434;
	public static final int ARM64_INS_LD1D = 435;
	public static final int ARM64_INS_LD1H = 436;
	public static final int ARM64_INS_LD1Q = 437;
	public static final int ARM64_INS_LD1R = 438;
	public static final int ARM64_INS_LD1RB = 439;
	public static final int ARM64_INS_LD1RD = 440;
	public static final int ARM64_INS_LD1RH = 441;
	public static final int ARM64_INS_LD1ROB = 442;
	public static final int ARM64_INS_LD1ROD = 443;
	public static final int ARM64_INS_LD1ROH = 444;
	public static final int ARM64_INS_LD1ROW = 445;
	public static final int ARM64_INS_LD1RQB = 446;
	public static final int ARM64_INS_LD1RQD = 447;
	public static final int ARM64_INS_LD1RQH = 448;
	public static final int ARM64_INS_LD1RQW = 449;
	public static final int ARM64_INS_LD1RSB = 450;
	public static final int ARM64_INS_LD1RSH = 451;
	public static final int ARM64_INS_LD1RSW = 452;
	public static final int ARM64_INS_LD1RW = 453;
	public static final int ARM64_INS_LD1SB = 454;
	public static final int ARM64_INS_LD1SH = 455;
	public static final int ARM64_INS_LD1SW = 456;
	public static final int ARM64_INS_LD1W = 457;
	public static final int ARM64_INS_LD2 = 458;
	public static final int ARM64_INS_LD2B = 459;
	public static final int ARM64_INS_LD2D = 460;
	public static final int ARM64_INS_LD2H = 461;
	public static final int ARM64_INS_LD2R = 462;
	public static final int ARM64_INS_LD2W = 463;
	public static final int ARM64_INS_LD3 = 464;
	public static final int ARM64_INS_LD3B = 465;
	public static final int ARM64_INS_LD3D = 466;
	public static final int ARM64_INS_LD3H = 467;
	public static final int ARM64_INS_LD3R = 468;
	public static final int ARM64_INS_LD3W = 469;
	public static final int ARM64_INS_LD4 = 470;
	public static final int ARM64_INS_LD4B = 471;
	public static final int ARM64_INS_LD4D = 472;
	public static final int ARM64_INS_LD4H = 473;
	public static final int ARM64_INS_LD4R = 474;
	public static final int ARM64_INS_LD4W = 475;
	public static final int ARM64_INS_LD64B = 476;
	public static final int ARM64_INS_LDADD = 477;
	public static final int ARM64_INS_LDADDA = 478;
	public static final int ARM64_INS_LDADDAB = 479;
	public static final int ARM64_INS_LDADDAH = 480;
	public static final int ARM64_INS_LDADDAL = 481;
	public static final int ARM64_INS_LDADDALB = 482;
	public static final int ARM64_INS_LDADDALH = 483;
	public static final int ARM64_INS_LDADDB = 484;
	public static final int ARM64_INS_LDADDH = 485;
	public static final int ARM64_INS_LDADDL = 486;
	public static final int ARM64_INS_LDADDLB = 487;
	public static final int ARM64_INS_LDADDLH = 488;
	public static final int ARM64_INS_LDAPR = 489;
	public static final int ARM64_INS_LDAPRB = 490;
	public static final int ARM64_INS_LDAPRH = 491;
	public static final int ARM64_INS_LDAPUR = 492;
	public static final int ARM64_INS_LDAPURB = 493;
	public static final int ARM64_INS_LDAPURH = 494;
	public static final int ARM64_INS_LDAPURSB = 495;
	public static final int ARM64_INS_LDAPURSH = 496;
	public static final int ARM64_INS_LDAPURSW = 497;
	public static final int ARM64_INS_LDAR = 498;
	public static final int ARM64_INS_LDARB = 499;
	public static final int ARM64_INS_LDARH = 500;
	public static final int ARM64_INS_LDAXP = 501;
	public static final int ARM64_INS_LDAXR = 502;
	public static final int ARM64_INS_LDAXRB = 503;
	public static final int ARM64_INS_LDAXRH = 504;
	public static final int ARM64_INS_LDCLR = 505;
	public static final int ARM64_INS_LDCLRA = 506;
	public static final int ARM64_INS_LDCLRAB = 507;
	public static final int ARM64_INS_LDCLRAH = 508;
	public static final int ARM64_INS_LDCLRAL = 509;
	public static final int ARM64_INS_LDCLRALB = 510;
	public static final int ARM64_INS_LDCLRALH = 511;
	public static final int ARM64_INS_LDCLRB = 512;
	public static final int ARM64_INS_LDCLRH = 513;
	public static final int ARM64_INS_LDCLRL = 514;
	public static final int ARM64_INS_LDCLRLB = 515;
	public static final int ARM64_INS_LDCLRLH = 516;
	public static final int ARM64_INS_LDEOR = 517;
	public static final int ARM64_INS_LDEORA = 518;
	public static final int ARM64_INS_LDEORAB = 519;
	public static final int ARM64_INS_LDEORAH = 520;
	public static final int ARM64_INS_LDEORAL = 521;
	public static final int ARM64_INS_LDEORALB = 522;
	public static final int ARM64_INS_LDEORALH = 523;
	public static final int ARM64_INS_LDEORB = 524;
	public static final int ARM64_INS_LDEORH = 525;
	public static final int ARM64_INS_LDEORL = 526;
	public static final int ARM64_INS_LDEORLB = 527;
	public static final int ARM64_INS_LDEORLH = 528;
	public static final int ARM64_INS_LDFF1B = 529;
	public static final int ARM64_INS_LDFF1D = 530;
	public static final int ARM64_INS_LDFF1H = 531;
	public static final int ARM64_INS_LDFF1SB = 532;
	public static final int ARM64_INS_LDFF1SH = 533;
	public static final int ARM64_INS_LDFF1SW = 534;
	public static final int ARM64_INS_LDFF1W = 535;
	public static final int ARM64_INS_LDG = 536;
	public static final int ARM64_INS_LDGM = 537;
	public static final int ARM64_INS_LDLAR = 538;
	public static final int ARM64_INS_LDLARB = 539;
	public static final int ARM64_INS_LDLARH = 540;
	public static final int ARM64_INS_LDNF1B = 541;
	public static final int ARM64_INS_LDNF1D = 542;
	public static final int ARM64_INS_LDNF1H = 543;
	public static final int ARM64_INS_LDNF1SB = 544;
	public static final int ARM64_INS_LDNF1SH = 545;
	public static final int ARM64_INS_LDNF1SW = 546;
	public static final int ARM64_INS_LDNF1W = 547;
	public static final int ARM64_INS_LDNP = 548;
	public static final int ARM64_INS_LDNT1B = 549;
	public static final int ARM64_INS_LDNT1D = 550;
	public static final int ARM64_INS_LDNT1H = 551;
	public static final int ARM64_INS_LDNT1SB = 552;
	public static final int ARM64_INS_LDNT1SH = 553;
	public static final int ARM64_INS_LDNT1SW = 554;
	public static final int ARM64_INS_LDNT1W = 555;
	public static final int ARM64_INS_LDP = 556;
	public static final int ARM64_INS_LDPSW = 557;
	public static final int ARM64_INS_LDR = 558;
	public static final int ARM64_INS_LDRAA = 559;
	public static final int ARM64_INS_LDRAB = 560;
	public static final int ARM64_INS_LDRB = 561;
	public static final int ARM64_INS_LDRH = 562;
	public static final int ARM64_INS_LDRSB = 563;
	public static final int ARM64_INS_LDRSH = 564;
	public static final int ARM64_INS_LDRSW = 565;
	public static final int ARM64_INS_LDSET = 566;
	public static final int ARM64_INS_LDSETA = 567;
	public static final int ARM64_INS_LDSETAB = 568;
	public static final int ARM64_INS_LDSETAH = 569;
	public static final int ARM64_INS_LDSETAL = 570;
	public static final int ARM64_INS_LDSETALB = 571;
	public static final int ARM64_INS_LDSETALH = 572;
	public static final int ARM64_INS_LDSETB = 573;
	public static final int ARM64_INS_LDSETH = 574;
	public static final int ARM64_INS_LDSETL = 575;
	public static final int ARM64_INS_LDSETLB = 576;
	public static final int ARM64_INS_LDSETLH = 577;
	public static final int ARM64_INS_LDSMAX = 578;
	public static final int ARM64_INS_LDSMAXA = 579;
	public static final int ARM64_INS_LDSMAXAB = 580;
	public static final int ARM64_INS_LDSMAXAH = 581;
	public static final int ARM64_INS_LDSMAXAL = 582;
	public static final int ARM64_INS_LDSMAXALB = 583;
	public static final int ARM64_INS_LDSMAXALH = 584;
	public static final int ARM64_INS_LDSMAXB = 585;
	public static final int ARM64_INS_LDSMAXH = 586;
	public static final int ARM64_INS_LDSMAXL = 587;
	public static final int ARM64_INS_LDSMAXLB = 588;
	public static final int ARM64_INS_LDSMAXLH = 589;
	public static final int ARM64_INS_LDSMIN = 590;
	public static final int ARM64_INS_LDSMINA = 591;
	public static final int ARM64_INS_LDSMINAB = 592;
	public static final int ARM64_INS_LDSMINAH = 593;
	public static final int ARM64_INS_LDSMINAL = 594;
	public static final int ARM64_INS_LDSMINALB = 595;
	public static final int ARM64_INS_LDSMINALH = 596;
	public static final int ARM64_INS_LDSMINB = 597;
	public static final int ARM64_INS_LDSMINH = 598;
	public static final int ARM64_INS_LDSMINL = 599;
	public static final int ARM64_INS_LDSMINLB = 600;
	public static final int ARM64_INS_LDSMINLH = 601;
	public static final int ARM64_INS_LDTR = 602;
	public static final int ARM64_INS_LDTRB = 603;
	public static final int ARM64_INS_LDTRH = 604;
	public static final int ARM64_INS_LDTRSB = 605;
	public static final int ARM64_INS_LDTRSH = 606;
	public static final int ARM64_INS_LDTRSW = 607;
	public static final int ARM64_INS_LDUMAX = 608;
	public static final int ARM64_INS_LDUMAXA = 609;
	public static final int ARM64_INS_LDUMAXAB = 610;
	public static final int ARM64_INS_LDUMAXAH = 611;
	public static final int ARM64_INS_LDUMAXAL = 612;
	public static final int ARM64_INS_LDUMAXALB = 613;
	public static final int ARM64_INS_LDUMAXALH = 614;
	public static final int ARM64_INS_LDUMAXB = 615;
	public static final int ARM64_INS_LDUMAXH = 616;
	public static final int ARM64_INS_LDUMAXL = 617;
	public static final int ARM64_INS_LDUMAXLB = 618;
	public static final int ARM64_INS_LDUMAXLH = 619;
	public static final int ARM64_INS_LDUMIN = 620;
	public static final int ARM64_INS_LDUMINA = 621;
	public static final int ARM64_INS_LDUMINAB = 622;
	public static final int ARM64_INS_LDUMINAH = 623;
	public static final int ARM64_INS_LDUMINAL = 624;
	public static final int ARM64_INS_LDUMINALB = 625;
	public static final int ARM64_INS_LDUMINALH = 626;
	public static final int ARM64_INS_LDUMINB = 627;
	public static final int ARM64_INS_LDUMINH = 628;
	public static final int ARM64_INS_LDUMINL = 629;
	public static final int ARM64_INS_LDUMINLB = 630;
	public static final int ARM64_INS_LDUMINLH = 631;
	public static final int ARM64_INS_LDUR = 632;
	public static final int ARM64_INS_LDURB = 633;
	public static final int ARM64_INS_LDURH = 634;
	public static final int ARM64_INS_LDURSB = 635;
	public static final int ARM64_INS_LDURSH = 636;
	public static final int ARM64_INS_LDURSW = 637;
	public static final int ARM64_INS_LDXP = 638;
	public static final int ARM64_INS_LDXR = 639;
	public static final int ARM64_INS_LDXRB = 640;
	public static final int ARM64_INS_LDXRH = 641;
	public static final int ARM64_INS_LSL = 642;
	public static final int ARM64_INS_LSLR = 643;
	public static final int ARM64_INS_LSLV = 644;
	public static final int ARM64_INS_LSR = 645;
	public static final int ARM64_INS_LSRR = 646;
	public static final int ARM64_INS_LSRV = 647;
	public static final int ARM64_INS_MAD = 648;
	public static final int ARM64_INS_MADD = 649;
	public static final int ARM64_INS_MATCH = 650;
	public static final int ARM64_INS_MLA = 651;
	public static final int ARM64_INS_MLS = 652;
	public static final int ARM64_INS_MNEG = 653;
	public static final int ARM64_INS_MOV = 654;
	public static final int ARM64_INS_MOVA = 655;
	public static final int ARM64_INS_MOVI = 656;
	public static final int ARM64_INS_MOVK = 657;
	public static final int ARM64_INS_MOVN = 658;
	public static final int ARM64_INS_MOVPRFX = 659;
	public static final int ARM64_INS_MOVS = 660;
	public static final int ARM64_INS_MOVZ = 661;
	public static final int ARM64_INS_MRS = 662;
	public static final int ARM64_INS_MSB = 663;
	public static final int ARM64_INS_MSR = 664;
	public static final int ARM64_INS_MSUB = 665;
	public static final int ARM64_INS_MUL = 666;
	public static final int ARM64_INS_MVN = 667;
	public static final int ARM64_INS_MVNI = 668;
	public static final int ARM64_INS_NAND = 669;
	public static final int ARM64_INS_NANDS = 670;
	public static final int ARM64_INS_NBSL = 671;
	public static final int ARM64_INS_NEG = 672;
	public static final int ARM64_INS_NEGS = 673;
	public static final int ARM64_INS_NGC = 674;
	public static final int ARM64_INS_NGCS = 675;
	public static final int ARM64_INS_NMATCH = 676;
	public static final int ARM64_INS_NOP = 677;
	public static final int ARM64_INS_NOR = 678;
	public static final int ARM64_INS_NORS = 679;
	public static final int ARM64_INS_NOT = 680;
	public static final int ARM64_INS_NOTS = 681;
	public static final int ARM64_INS_ORN = 682;
	public static final int ARM64_INS_ORNS = 683;
	public static final int ARM64_INS_ORR = 684;
	public static final int ARM64_INS_ORRS = 685;
	public static final int ARM64_INS_ORV = 686;
	public static final int ARM64_INS_PACDA = 687;
	public static final int ARM64_INS_PACDB = 688;
	public static final int ARM64_INS_PACDZA = 689;
	public static final int ARM64_INS_PACDZB = 690;
	public static final int ARM64_INS_PACGA = 691;
	public static final int ARM64_INS_PACIA = 692;
	public static final int ARM64_INS_PACIA1716 = 693;
	public static final int ARM64_INS_PACIASP = 694;
	public static final int ARM64_INS_PACIAZ = 695;
	public static final int ARM64_INS_PACIB = 696;
	public static final int ARM64_INS_PACIB1716 = 697;
	public static final int ARM64_INS_PACIBSP = 698;
	public static final int ARM64_INS_PACIBZ = 699;
	public static final int ARM64_INS_PACIZA = 700;
	public static final int ARM64_INS_PACIZB = 701;
	public static final int ARM64_INS_PFALSE = 702;
	public static final int ARM64_INS_PFIRST = 703;
	public static final int ARM64_INS_PMUL = 704;
	public static final int ARM64_INS_PMULL = 705;
	public static final int ARM64_INS_PMULL2 = 706;
	public static final int ARM64_INS_PMULLB = 707;
	public static final int ARM64_INS_PMULLT = 708;
	public static final int ARM64_INS_PNEXT = 709;
	public static final int ARM64_INS_PRFB = 710;
	public static final int ARM64_INS_PRFD = 711;
	public static final int ARM64_INS_PRFH = 712;
	public static final int ARM64_INS_PRFM = 713;
	public static final int ARM64_INS_PRFUM = 714;
	public static final int ARM64_INS_PRFW = 715;
	public static final int ARM64_INS_PSB = 716;
	public static final int ARM64_INS_PSEL = 717;
	public static final int ARM64_INS_PSSBB = 718;
	public static final int ARM64_INS_PTEST = 719;
	public static final int ARM64_INS_PTRUE = 720;
	public static final int ARM64_INS_PTRUES = 721;
	public static final int ARM64_INS_PUNPKHI = 722;
	public static final int ARM64_INS_PUNPKLO = 723;
	public static final int ARM64_INS_RADDHN = 724;
	public static final int ARM64_INS_RADDHN2 = 725;
	public static final int ARM64_INS_RADDHNB = 726;
	public static final int ARM64_INS_RADDHNT = 727;
	public static final int ARM64_INS_RAX1 = 728;
	public static final int ARM64_INS_RBIT = 729;
	public static final int ARM64_INS_RDFFR = 730;
	public static final int ARM64_INS_RDFFRS = 731;
	public static final int ARM64_INS_RDVL = 732;
	public static final int ARM64_INS_RET = 733;
	public static final int ARM64_INS_RETAA = 734;
	public static final int ARM64_INS_RETAB = 735;
	public static final int ARM64_INS_REV = 736;
	public static final int ARM64_INS_REV16 = 737;
	public static final int ARM64_INS_REV32 = 738;
	public static final int ARM64_INS_REV64 = 739;
	public static final int ARM64_INS_REVB = 740;
	public static final int ARM64_INS_REVD = 741;
	public static final int ARM64_INS_REVH = 742;
	public static final int ARM64_INS_REVW = 743;
	public static final int ARM64_INS_RMIF = 744;
	public static final int ARM64_INS_ROR = 745;
	public static final int ARM64_INS_RORV = 746;
	public static final int ARM64_INS_RSHRN = 747;
	public static final int ARM64_INS_RSHRN2 = 748;
	public static final int ARM64_INS_RSHRNB = 749;
	public static final int ARM64_INS_RSHRNT = 750;
	public static final int ARM64_INS_RSUBHN = 751;
	public static final int ARM64_INS_RSUBHN2 = 752;
	public static final int ARM64_INS_RSUBHNB = 753;
	public static final int ARM64_INS_RSUBHNT = 754;
	public static final int ARM64_INS_SABA = 755;
	public static final int ARM64_INS_SABAL = 756;
	public static final int ARM64_INS_SABAL2 = 757;
	public static final int ARM64_INS_SABALB = 758;
	public static final int ARM64_INS_SABALT = 759;
	public static final int ARM64_INS_SABD = 760;
	public static final int ARM64_INS_SABDL = 761;
	public static final int ARM64_INS_SABDL2 = 762;
	public static final int ARM64_INS_SABDLB = 763;
	public static final int ARM64_INS_SABDLT = 764;
	public static final int ARM64_INS_SADALP = 765;
	public static final int ARM64_INS_SADDL = 766;
	public static final int ARM64_INS_SADDL2 = 767;
	public static final int ARM64_INS_SADDLB = 768;
	public static final int ARM64_INS_SADDLBT = 769;
	public static final int ARM64_INS_SADDLP = 770;
	public static final int ARM64_INS_SADDLT = 771;
	public static final int ARM64_INS_SADDLV = 772;
	public static final int ARM64_INS_SADDV = 773;
	public static final int ARM64_INS_SADDW = 774;
	public static final int ARM64_INS_SADDW2 = 775;
	public static final int ARM64_INS_SADDWB = 776;
	public static final int ARM64_INS_SADDWT = 777;
	public static final int ARM64_INS_SB = 778;
	public static final int ARM64_INS_SBC = 779;
	public static final int ARM64_INS_SBCLB = 780;
	public static final int ARM64_INS_SBCLT = 781;
	public static final int ARM64_INS_SBCS = 782;
	public static final int ARM64_INS_SBFM = 783;
	public static final int ARM64_INS_SCLAMP = 784;
	public static final int ARM64_INS_SCVTF = 785;
	public static final int ARM64_INS_SDIV = 786;
	public static final int ARM64_INS_SDIVR = 787;
	public static final int ARM64_INS_SDOT = 788;
	public static final int ARM64_INS_SEL = 789;
	public static final int ARM64_INS_SETE = 790;
	public static final int ARM64_INS_SETEN = 791;
	public static final int ARM64_INS_SETET = 792;
	public static final int ARM64_INS_SETETN = 793;
	public static final int ARM64_INS_SETF16 = 794;
	public static final int ARM64_INS_SETF8 = 795;
	public static final int ARM64_INS_SETFFR = 796;
	public static final int ARM64_INS_SETGE = 797;
	public static final int ARM64_INS_SETGEN = 798;
	public static final int ARM64_INS_SETGET = 799;
	public static final int ARM64_INS_SETGETN = 800;
	public static final int ARM64_INS_SETGM = 801;
	public static final int ARM64_INS_SETGMN = 802;
	public static final int ARM64_INS_SETGMT = 803;
	public static final int ARM64_INS_SETGMTN = 804;
	public static final int ARM64_INS_SETGP = 805;
	public static final int ARM64_INS_SETGPN = 806;
	public static final int ARM64_INS_SETGPT = 807;
	public static final int ARM64_INS_SETGPTN = 808;
	public static final int ARM64_INS_SETM = 809;
	public static final int ARM64_INS_SETMN = 810;
	public static final int ARM64_INS_SETMT = 811;
	public static final int ARM64_INS_SETMTN = 812;
	public static final int ARM64_INS_SETP = 813;
	public static final int ARM64_INS_SETPN = 814;
	public static final int ARM64_INS_SETPT = 815;
	public static final int ARM64_INS_SETPTN = 816;
	public static final int ARM64_INS_SEV = 817;
	public static final int ARM64_INS_SEVL = 818;
	public static final int ARM64_INS_SHA1C = 819;
	public static final int ARM64_INS_SHA1H = 820;
	public static final int ARM64_INS_SHA1M = 821;
	public static final int ARM64_INS_SHA1P = 822;
	public static final int ARM64_INS_SHA1SU0 = 823;
	public static final int ARM64_INS_SHA1SU1 = 824;
	public static final int ARM64_INS_SHA256H = 825;
	public static final int ARM64_INS_SHA256H2 = 826;
	public static final int ARM64_INS_SHA256SU0 = 827;
	public static final int ARM64_INS_SHA256SU1 = 828;
	public static final int ARM64_INS_SHA512H = 829;
	public static final int ARM64_INS_SHA512H2 = 830;
	public static final int ARM64_INS_SHA512SU0 = 831;
	public static final int ARM64_INS_SHA512SU1 = 832;
	public static final int ARM64_INS_SHADD = 833;
	public static final int ARM64_INS_SHL = 834;
	public static final int ARM64_INS_SHLL = 835;
	public static final int ARM64_INS_SHLL2 = 836;
	public static final int ARM64_INS_SHRN = 837;
	public static final int ARM64_INS_SHRN2 = 838;
	public static final int ARM64_INS_SHRNB = 839;
	public static final int ARM64_INS_SHRNT = 840;
	public static final int ARM64_INS_SHSUB = 841;
	public static final int ARM64_INS_SHSUBR = 842;
	public static final int ARM64_INS_SLI = 843;
	public static final int ARM64_INS_SM3PARTW1 = 844;
	public static final int ARM64_INS_SM3PARTW2 = 845;
	public static final int ARM64_INS_SM3SS1 = 846;
	public static final int ARM64_INS_SM3TT1A = 847;
	public static final int ARM64_INS_SM3TT1B = 848;
	public static final int ARM64_INS_SM3TT2A = 849;
	public static final int ARM64_INS_SM3TT2B = 850;
	public static final int ARM64_INS_SM4E = 851;
	public static final int ARM64_INS_SM4EKEY = 852;
	public static final int ARM64_INS_SMADDL = 853;
	public static final int ARM64_INS_SMAX = 854;
	public static final int ARM64_INS_SMAXP = 855;
	public static final int ARM64_INS_SMAXV = 856;
	public static final int ARM64_INS_SMC = 857;
	public static final int ARM64_INS_SMIN = 858;
	public static final int ARM64_INS_SMINP = 859;
	public static final int ARM64_INS_SMINV = 860;
	public static final int ARM64_INS_SMLAL = 861;
	public static final int ARM64_INS_SMLAL2 = 862;
	public static final int ARM64_INS_SMLALB = 863;
	public static final int ARM64_INS_SMLALT = 864;
	public static final int ARM64_INS_SMLSL = 865;
	public static final int ARM64_INS_SMLSL2 = 866;
	public static final int ARM64_INS_SMLSLB = 867;
	public static final int ARM64_INS_SMLSLT = 868;
	public static final int ARM64_INS_SMMLA = 869;
	public static final int ARM64_INS_SMNEGL = 870;
	public static final int ARM64_INS_SMOPA = 871;
	public static final int ARM64_INS_SMOPS = 872;
	public static final int ARM64_INS_SMOV = 873;
	public static final int ARM64_INS_SMSTART = 874;
	public static final int ARM64_INS_SMSTOP = 875;
	public static final int ARM64_INS_SMSUBL = 876;
	public static final int ARM64_INS_SMULH = 877;
	public static final int ARM64_INS_SMULL = 878;
	public static final int ARM64_INS_SMULL2 = 879;
	public static final int ARM64_INS_SMULLB = 880;
	public static final int ARM64_INS_SMULLT = 881;
	public static final int ARM64_INS_SPLICE = 882;
	public static final int ARM64_INS_SQABS = 883;
	public static final int ARM64_INS_SQADD = 884;
	public static final int ARM64_INS_SQCADD = 885;
	public static final int ARM64_INS_SQDECB = 886;
	public static final int ARM64_INS_SQDECD = 887;
	public static final int ARM64_INS_SQDECH = 888;
	public static final int ARM64_INS_SQDECP = 889;
	public static final int ARM64_INS_SQDECW = 890;
	public static final int ARM64_INS_SQDMLAL = 891;
	public static final int ARM64_INS_SQDMLAL2 = 892;
	public static final int ARM64_INS_SQDMLALB = 893;
	public static final int ARM64_INS_SQDMLALBT = 894;
	public static final int ARM64_INS_SQDMLALT = 895;
	public static final int ARM64_INS_SQDMLSL = 896;
	public static final int ARM64_INS_SQDMLSL2 = 897;
	public static final int ARM64_INS_SQDMLSLB = 898;
	public static final int ARM64_INS_SQDMLSLBT = 899;
	public static final int ARM64_INS_SQDMLSLT = 900;
	public static final int ARM64_INS_SQDMULH = 901;
	public static final int ARM64_INS_SQDMULL = 902;
	public static final int ARM64_INS_SQDMULL2 = 903;
	public static final int ARM64_INS_SQDMULLB = 904;
	public static final int ARM64_INS_SQDMULLT = 905;
	public static final int ARM64_INS_SQINCB = 906;
	public static final int ARM64_INS_SQINCD = 907;
	public static final int ARM64_INS_SQINCH = 908;
	public static final int ARM64_INS_SQINCP = 909;
	public static final int ARM64_INS_SQINCW = 910;
	public static final int ARM64_INS_SQNEG = 911;
	public static final int ARM64_INS_SQRDCMLAH = 912;
	public static final int ARM64_INS_SQRDMLAH = 913;
	public static final int ARM64_INS_SQRDMLSH = 914;
	public static final int ARM64_INS_SQRDMULH = 915;
	public static final int ARM64_INS_SQRSHL = 916;
	public static final int ARM64_INS_SQRSHLR = 917;
	public static final int ARM64_INS_SQRSHRN = 918;
	public static final int ARM64_INS_SQRSHRN2 = 919;
	public static final int ARM64_INS_SQRSHRNB = 920;
	public static final int ARM64_INS_SQRSHRNT = 921;
	public static final int ARM64_INS_SQRSHRUN = 922;
	public static final int ARM64_INS_SQRSHRUN2 = 923;
	public static final int ARM64_INS_SQRSHRUNB = 924;
	public static final int ARM64_INS_SQRSHRUNT = 925;
	public static final int ARM64_INS_SQSHL = 926;
	public static final int ARM64_INS_SQSHLR = 927;
	public static final int ARM64_INS_SQSHLU = 928;
	public static final int ARM64_INS_SQSHRN = 929;
	public static final int ARM64_INS_SQSHRN2 = 930;
	public static final int ARM64_INS_SQSHRNB = 931;
	public static final int ARM64_INS_SQSHRNT = 932;
	public static final int ARM64_INS_SQSHRUN = 933;
	public static final int ARM64_INS_SQSHRUN2 = 934;
	public static final int ARM64_INS_SQSHRUNB = 935;
	public static final int ARM64_INS_SQSHRUNT = 936;
	public static final int ARM64_INS_SQSUB = 937;
	public static final int ARM64_INS_SQSUBR = 938;
	public static final int ARM64_INS_SQXTN = 939;
	public static final int ARM64_INS_SQXTN2 = 940;
	public static final int ARM64_INS_SQXTNB = 941;
	public static final int ARM64_INS_SQXTNT = 942;
	public static final int ARM64_INS_SQXTUN = 943;
	public static final int ARM64_INS_SQXTUN2 = 944;
	public static final int ARM64_INS_SQXTUNB = 945;
	public static final int ARM64_INS_SQXTUNT = 946;
	public static final int ARM64_INS_SRHADD = 947;
	public static final int ARM64_INS_SRI = 948;
	public static final int ARM64_INS_SRSHL = 949;
	public static final int ARM64_INS_SRSHLR = 950;
	public static final int ARM64_INS_SRSHR = 951;
	public static final int ARM64_INS_SRSRA = 952;
	public static final int ARM64_INS_SSBB = 953;
	public static final int ARM64_INS_SSHL = 954;
	public static final int ARM64_INS_SSHLL = 955;
	public static final int ARM64_INS_SSHLL2 = 956;
	public static final int ARM64_INS_SSHLLB = 957;
	public static final int ARM64_INS_SSHLLT = 958;
	public static final int ARM64_INS_SSHR = 959;
	public static final int ARM64_INS_SSRA = 960;
	public static final int ARM64_INS_SSUBL = 961;
	public static final int ARM64_INS_SSUBL2 = 962;
	public static final int ARM64_INS_SSUBLB = 963;
	public static final int ARM64_INS_SSUBLBT = 964;
	public static final int ARM64_INS_SSUBLT = 965;
	public static final int ARM64_INS_SSUBLTB = 966;
	public static final int ARM64_INS_SSUBW = 967;
	public static final int ARM64_INS_SSUBW2 = 968;
	public static final int ARM64_INS_SSUBWB = 969;
	public static final int ARM64_INS_SSUBWT = 970;
	public static final int ARM64_INS_ST1 = 971;
	public static final int ARM64_INS_ST1B = 972;
	public static final int ARM64_INS_ST1D = 973;
	public static final int ARM64_INS_ST1H = 974;
	public static final int ARM64_INS_ST1Q = 975;
	public static final int ARM64_INS_ST1W = 976;
	public static final int ARM64_INS_ST2 = 977;
	public static final int ARM64_INS_ST2B = 978;
	public static final int ARM64_INS_ST2D = 979;
	public static final int ARM64_INS_ST2G = 980;
	public static final int ARM64_INS_ST2H = 981;
	public static final int ARM64_INS_ST2W = 982;
	public static final int ARM64_INS_ST3 = 983;
	public static final int ARM64_INS_ST3B = 984;
	public static final int ARM64_INS_ST3D = 985;
	public static final int ARM64_INS_ST3H = 986;
	public static final int ARM64_INS_ST3W = 987;
	public static final int ARM64_INS_ST4 = 988;
	public static final int ARM64_INS_ST4B = 989;
	public static final int ARM64_INS_ST4D = 990;
	public static final int ARM64_INS_ST4H = 991;
	public static final int ARM64_INS_ST4W = 992;
	public static final int ARM64_INS_ST64B = 993;
	public static final int ARM64_INS_ST64BV = 994;
	public static final int ARM64_INS_ST64BV0 = 995;
	public static final int ARM64_INS_STADD = 996;
	public static final int ARM64_INS_STADDB = 997;
	public static final int ARM64_INS_STADDH = 998;
	public static final int ARM64_INS_STADDL = 999;
	public static final int ARM64_INS_STADDLB = 1000;
	public static final int ARM64_INS_STADDLH = 1001;
	public static final int ARM64_INS_STCLR = 1002;
	public static final int ARM64_INS_STCLRB = 1003;
	public static final int ARM64_INS_STCLRH = 1004;
	public static final int ARM64_INS_STCLRL = 1005;
	public static final int ARM64_INS_STCLRLB = 1006;
	public static final int ARM64_INS_STCLRLH = 1007;
	public static final int ARM64_INS_STEOR = 1008;
	public static final int ARM64_INS_STEORB = 1009;
	public static final int ARM64_INS_STEORH = 1010;
	public static final int ARM64_INS_STEORL = 1011;
	public static final int ARM64_INS_STEORLB = 1012;
	public static final int ARM64_INS_STEORLH = 1013;
	public static final int ARM64_INS_STG = 1014;
	public static final int ARM64_INS_STGM = 1015;
	public static final int ARM64_INS_STGP = 1016;
	public static final int ARM64_INS_STLLR = 1017;
	public static final int ARM64_INS_STLLRB = 1018;
	public static final int ARM64_INS_STLLRH = 1019;
	public static final int ARM64_INS_STLR = 1020;
	public static final int ARM64_INS_STLRB = 1021;
	public static final int ARM64_INS_STLRH = 1022;
	public static final int ARM64_INS_STLUR = 1023;
	public static final int ARM64_INS_STLURB = 1024;
	public static final int ARM64_INS_STLURH = 1025;
	public static final int ARM64_INS_STLXP = 1026;
	public static final int ARM64_INS_STLXR = 1027;
	public static final int ARM64_INS_STLXRB = 1028;
	public static final int ARM64_INS_STLXRH = 1029;
	public static final int ARM64_INS_STNP = 1030;
	public static final int ARM64_INS_STNT1B = 1031;
	public static final int ARM64_INS_STNT1D = 1032;
	public static final int ARM64_INS_STNT1H = 1033;
	public static final int ARM64_INS_STNT1W = 1034;
	public static final int ARM64_INS_STP = 1035;
	public static final int ARM64_INS_STR = 1036;
	public static final int ARM64_INS_STRB = 1037;
	public static final int ARM64_INS_STRH = 1038;
	public static final int ARM64_INS_STSET = 1039;
	public static final int ARM64_INS_STSETB = 1040;
	public static final int ARM64_INS_STSETH = 1041;
	public static final int ARM64_INS_STSETL = 1042;
	public static final int ARM64_INS_STSETLB = 1043;
	public static final int ARM64_INS_STSETLH = 1044;
	public static final int ARM64_INS_STSMAX = 1045;
	public static final int ARM64_INS_STSMAXB = 1046;
	public static final int ARM64_INS_STSMAXH = 1047;
	public static final int ARM64_INS_STSMAXL = 1048;
	public static final int ARM64_INS_STSMAXLB = 1049;
	public static final int ARM64_INS_STSMAXLH = 1050;
	public static final int ARM64_INS_STSMIN = 1051;
	public static final int ARM64_INS_STSMINB = 1052;
	public static final int ARM64_INS_STSMINH = 1053;
	public static final int ARM64_INS_STSMINL = 1054;
	public static final int ARM64_INS_STSMINLB = 1055;
	public static final int ARM64_INS_STSMINLH = 1056;
	public static final int ARM64_INS_STTR = 1057;
	public static final int ARM64_INS_STTRB = 1058;
	public static final int ARM64_INS_STTRH = 1059;
	public static final int ARM64_INS_STUMAX = 1060;
	public static final int ARM64_INS_STUMAXB = 1061;
	public static final int ARM64_INS_STUMAXH = 1062;
	public static final int ARM64_INS_STUMAXL = 1063;
	public static final int ARM64_INS_STUMAXLB = 1064;
	public static final int ARM64_INS_STUMAXLH = 1065;
	public static final int ARM64_INS_STUMIN = 1066;
	public static final int ARM64_INS_STUMINB = 1067;
	public static final int ARM64_INS_STUMINH = 1068;
	public static final int ARM64_INS_STUMINL = 1069;
	public static final int ARM64_INS_STUMINLB = 1070;
	public static final int ARM64_INS_STUMINLH = 1071;
	public static final int ARM64_INS_STUR = 1072;
	public static final int ARM64_INS_STURB = 1073;
	public static final int ARM64_INS_STURH = 1074;
	public static final int ARM64_INS_STXP = 1075;
	public static final int ARM64_INS_STXR = 1076;
	public static final int ARM64_INS_STXRB = 1077;
	public static final int ARM64_INS_STXRH = 1078;
	public static final int ARM64_INS_STZ2G = 1079;
	public static final int ARM64_INS_STZG = 1080;
	public static final int ARM64_INS_STZGM = 1081;
	public static final int ARM64_INS_SUB = 1082;
	public static final int ARM64_INS_SUBG = 1083;
	public static final int ARM64_INS_SUBHN = 1084;
	public static final int ARM64_INS_SUBHN2 = 1085;
	public static final int ARM64_INS_SUBHNB = 1086;
	public static final int ARM64_INS_SUBHNT = 1087;
	public static final int ARM64_INS_SUBP = 1088;
	public static final int ARM64_INS_SUBPS = 1089;
	public static final int ARM64_INS_SUBR = 1090;
	public static final int ARM64_INS_SUBS = 1091;
	public static final int ARM64_INS_SUDOT = 1092;
	public static final int ARM64_INS_SUMOPA = 1093;
	public static final int ARM64_INS_SUMOPS = 1094;
	public static final int ARM64_INS_SUNPKHI = 1095;
	public static final int ARM64_INS_SUNPKLO = 1096;
	public static final int ARM64_INS_SUQADD = 1097;
	public static final int ARM64_INS_SVC = 1098;
	public static final int ARM64_INS_SWP = 1099;
	public static final int ARM64_INS_SWPA = 1100;
	public static final int ARM64_INS_SWPAB = 1101;
	public static final int ARM64_INS_SWPAH = 1102;
	public static final int ARM64_INS_SWPAL = 1103;
	public static final int ARM64_INS_SWPALB = 1104;
	public static final int ARM64_INS_SWPALH = 1105;
	public static final int ARM64_INS_SWPB = 1106;
	public static final int ARM64_INS_SWPH = 1107;
	public static final int ARM64_INS_SWPL = 1108;
	public static final int ARM64_INS_SWPLB = 1109;
	public static final int ARM64_INS_SWPLH = 1110;
	public static final int ARM64_INS_SXTB = 1111;
	public static final int ARM64_INS_SXTH = 1112;
	public static final int ARM64_INS_SXTL = 1113;
	public static final int ARM64_INS_SXTL2 = 1114;
	public static final int ARM64_INS_SXTW = 1115;
	public static final int ARM64_INS_SYS = 1116;
	public static final int ARM64_INS_SYSL = 1117;
	public static final int ARM64_INS_TBL = 1118;
	public static final int ARM64_INS_TBNZ = 1119;
	public static final int ARM64_INS_TBX = 1120;
	public static final int ARM64_INS_TBZ = 1121;
	public static final int ARM64_INS_TCANCEL = 1122;
	public static final int ARM64_INS_TCOMMIT = 1123;
	public static final int ARM64_INS_TRN1 = 1124;
	public static final int ARM64_INS_TRN2 = 1125;
	public static final int ARM64_INS_TSB = 1126;
	public static final int ARM64_INS_TST = 1127;
	public static final int ARM64_INS_TSTART = 1128;
	public static final int ARM64_INS_TTEST = 1129;
	public static final int ARM64_INS_UABA = 1130;
	public static final int ARM64_INS_UABAL = 1131;
	public static final int ARM64_INS_UABAL2 = 1132;
	public static final int ARM64_INS_UABALB = 1133;
	public static final int ARM64_INS_UABALT = 1134;
	public static final int ARM64_INS_UABD = 1135;
	public static final int ARM64_INS_UABDL = 1136;
	public static final int ARM64_INS_UABDL2 = 1137;
	public static final int ARM64_INS_UABDLB = 1138;
	public static final int ARM64_INS_UABDLT = 1139;
	public static final int ARM64_INS_UADALP = 1140;
	public static final int ARM64_INS_UADDL = 1141;
	public static final int ARM64_INS_UADDL2 = 1142;
	public static final int ARM64_INS_UADDLB = 1143;
	public static final int ARM64_INS_UADDLP = 1144;
	public static final int ARM64_INS_UADDLT = 1145;
	public static final int ARM64_INS_UADDLV = 1146;
	public static final int ARM64_INS_UADDV = 1147;
	public static final int ARM64_INS_UADDW = 1148;
	public static final int ARM64_INS_UADDW2 = 1149;
	public static final int ARM64_INS_UADDWB = 1150;
	public static final int ARM64_INS_UADDWT = 1151;
	public static final int ARM64_INS_UBFM = 1152;
	public static final int ARM64_INS_UCLAMP = 1153;
	public static final int ARM64_INS_UCVTF = 1154;
	public static final int ARM64_INS_UDF = 1155;
	public static final int ARM64_INS_UDIV = 1156;
	public static final int ARM64_INS_UDIVR = 1157;
	public static final int ARM64_INS_UDOT = 1158;
	public static final int ARM64_INS_UHADD = 1159;
	public static final int ARM64_INS_UHSUB = 1160;
	public static final int ARM64_INS_UHSUBR = 1161;
	public static final int ARM64_INS_UMADDL = 1162;
	public static final int ARM64_INS_UMAX = 1163;
	public static final int ARM64_INS_UMAXP = 1164;
	public static final int ARM64_INS_UMAXV = 1165;
	public static final int ARM64_INS_UMIN = 1166;
	public static final int ARM64_INS_UMINP = 1167;
	public static final int ARM64_INS_UMINV = 1168;
	public static final int ARM64_INS_UMLAL = 1169;
	public static final int ARM64_INS_UMLAL2 = 1170;
	public static final int ARM64_INS_UMLALB = 1171;
	public static final int ARM64_INS_UMLALT = 1172;
	public static final int ARM64_INS_UMLSL = 1173;
	public static final int ARM64_INS_UMLSL2 = 1174;
	public static final int ARM64_INS_UMLSLB = 1175;
	public static final int ARM64_INS_UMLSLT = 1176;
	public static final int ARM64_INS_UMMLA = 1177;
	public static final int ARM64_INS_UMNEGL = 1178;
	public static final int ARM64_INS_UMOPA = 1179;
	public static final int ARM64_INS_UMOPS = 1180;
	public static final int ARM64_INS_UMOV = 1181;
	public static final int ARM64_INS_UMSUBL = 1182;
	public static final int ARM64_INS_UMULH = 1183;
	public static final int ARM64_INS_UMULL = 1184;
	public static final int ARM64_INS_UMULL2 = 1185;
	public static final int ARM64_INS_UMULLB = 1186;
	public static final int ARM64_INS_UMULLT = 1187;
	public static final int ARM64_INS_UQADD = 1188;
	public static final int ARM64_INS_UQDECB = 1189;
	public static final int ARM64_INS_UQDECD = 1190;
	public static final int ARM64_INS_UQDECH = 1191;
	public static final int ARM64_INS_UQDECP = 1192;
	public static final int ARM64_INS_UQDECW = 1193;
	public static final int ARM64_INS_UQINCB = 1194;
	public static final int ARM64_INS_UQINCD = 1195;
	public static final int ARM64_INS_UQINCH = 1196;
	public static final int ARM64_INS_UQINCP = 1197;
	public static final int ARM64_INS_UQINCW = 1198;
	public static final int ARM64_INS_UQRSHL = 1199;
	public static final int ARM64_INS_UQRSHLR = 1200;
	public static final int ARM64_INS_UQRSHRN = 1201;
	public static final int ARM64_INS_UQRSHRN2 = 1202;
	public static final int ARM64_INS_UQRSHRNB = 1203;
	public static final int ARM64_INS_UQRSHRNT = 1204;
	public static final int ARM64_INS_UQSHL = 1205;
	public static final int ARM64_INS_UQSHLR = 1206;
	public static final int ARM64_INS_UQSHRN = 1207;
	public static final int ARM64_INS_UQSHRN2 = 1208;
	public static final int ARM64_INS_UQSHRNB = 1209;
	public static final int ARM64_INS_UQSHRNT = 1210;
	public static final int ARM64_INS_UQSUB = 1211;
	public static final int ARM64_INS_UQSUBR = 1212;
	public static final int ARM64_INS_UQXTN = 1213;
	public static final int ARM64_INS_UQXTN2 = 1214;
	public static final int ARM64_INS_UQXTNB = 1215;
	public static final int ARM64_INS_UQXTNT = 1216;
	public static final int ARM64_INS_URECPE = 1217;
	public static final int ARM64_INS_URHADD = 1218;
	public static final int ARM64_INS_URSHL = 1219;
	public static final int ARM64_INS_URSHLR = 1220;
	public static final int ARM64_INS_URSHR = 1221;
	public static final int ARM64_INS_URSQRTE = 1222;
	public static final int ARM64_INS_URSRA = 1223;
	public static final int ARM64_INS_USDOT = 1224;
	public static final int ARM64_INS_USHL = 1225;
	public static final int ARM64_INS_USHLL = 1226;
	public static final int ARM64_INS_USHLL2 = 1227;
	public static final int ARM64_INS_USHLLB = 1228;
	public static final int ARM64_INS_USHLLT = 1229;
	public static final int ARM64_INS_USHR = 1230;
	public static final int ARM64_INS_USMMLA = 1231;
	public static final int ARM64_INS_USMOPA = 1232;
	public static final int ARM64_INS_USMOPS = 1233;
	public static final int ARM64_INS_USQADD = 1234;
	public static final int ARM64_INS_USRA = 1235;
	public static final int ARM64_INS_USUBL = 1236;
	public static final int ARM64_INS_USUBL2 = 1237;
	public static final int ARM64_INS_USUBLB = 1238;
	public static final int ARM64_INS_USUBLT = 1239;
	public static final int ARM64_INS_USUBW = 1240;
	public static final int ARM64_INS_USUBW2 = 1241;
	public static final int ARM64_INS_USUBWB = 1242;
	public static final int ARM64_INS_USUBWT = 1243;
	public static final int ARM64_INS_UUNPKHI = 1244;
	public static final int ARM64_INS_UUNPKLO = 1245;
	public static final int ARM64_INS_UXTB = 1246;
	public static final int ARM64_INS_UXTH = 1247;
	public static final int ARM64_INS_UXTL = 1248;
	public static final int ARM64_INS_UXTL2 = 1249;
	public static final int ARM64_INS_UXTW = 1250;
	public static final int ARM64_INS_UZP1 = 1251;
	public static final int ARM64_INS_UZP2 = 1252;
	public static final int ARM64_INS_WFE = 1253;
	public static final int ARM64_INS_WFET = 1254;
	public static final int ARM64_INS_WFI = 1255;
	public static final int ARM64_INS_WFIT = 1256;
	public static final int ARM64_INS_WHILEGE = 1257;
	public static final int ARM64_INS_WHILEGT = 1258;
	public static final int ARM64_INS_WHILEHI = 1259;
	public static final int ARM64_INS_WHILEHS = 1260;
	public static final int ARM64_INS_WHILELE = 1261;
	public static final int ARM64_INS_WHILELO = 1262;
	public static final int ARM64_INS_WHILELS = 1263;
	public static final int ARM64_INS_WHILELT = 1264;
	public static final int ARM64_INS_WHILERW = 1265;
	public static final int ARM64_INS_WHILEWR = 1266;
	public static final int ARM64_INS_WRFFR = 1267;
	public static final int ARM64_INS_XAFLAG = 1268;
	public static final int ARM64_INS_XAR = 1269;
	public static final int ARM64_INS_XPACD = 1270;
	public static final int ARM64_INS_XPACI = 1271;
	public static final int ARM64_INS_XPACLRI = 1272;
	public static final int ARM64_INS_XTN = 1273;
	public static final int ARM64_INS_XTN2 = 1274;
	public static final int ARM64_INS_YIELD = 1275;
	public static final int ARM64_INS_ZERO = 1276;
	public static final int ARM64_INS_ZIP1 = 1277;
	public static final int ARM64_INS_ZIP2 = 1278;
	public static final int ARM64_INS_SBFIZ = 1279;
	public static final int ARM64_INS_UBFIZ = 1280;
	public static final int ARM64_INS_SBFX = 1281;
	public static final int ARM64_INS_UBFX = 1282;
	public static final int ARM64_INS_BFI = 1283;
	public static final int ARM64_INS_BFXIL = 1284;
	public static final int ARM64_INS_IC = 1285;
	public static final int ARM64_INS_DC = 1286;
	public static final int ARM64_INS_AT = 1287;
	public static final int ARM64_INS_TLBI = 1288;
	public static final int ARM64_INS_ENDING = 1289;

	public static final int ARM64_GRP_INVALID = 0;
	public static final int ARM64_GRP_JUMP = 1;
	public static final int ARM64_GRP_CALL = 2;
	public static final int ARM64_GRP_RET = 3;
	public static final int ARM64_GRP_INT = 4;
	public static final int ARM64_GRP_PRIVILEGE = 6;
	public static final int ARM64_GRP_BRANCH_RELATIVE = 7;
	public static final int ARM64_GRP_PAC = 8;
	public static final int ARM64_GRP_CRYPTO = 128;
	public static final int ARM64_GRP_FPARMV8 = 129;
	public static final int ARM64_GRP_NEON = 130;
	public static final int ARM64_GRP_CRC = 131;
	public static final int ARM64_GRP_AES = 132;
	public static final int ARM64_GRP_DOTPROD = 133;
	public static final int ARM64_GRP_FULLFP16 = 134;
	public static final int ARM64_GRP_LSE = 135;
	public static final int ARM64_GRP_RCPC = 136;
	public static final int ARM64_GRP_RDM = 137;
	public static final int ARM64_GRP_SHA2 = 138;
	public static final int ARM64_GRP_SHA3 = 139;
	public static final int ARM64_GRP_SM4 = 140;
	public static final int ARM64_GRP_SVE = 141;
	public static final int ARM64_GRP_SVE2 = 142;
	public static final int ARM64_GRP_SVE2AES = 143;
	public static final int ARM64_GRP_SVE2BitPerm = 144;
	public static final int ARM64_GRP_SVE2SHA3 = 145;
	public static final int ARM64_GRP_SVE2SM4 = 146;
	public static final int ARM64_GRP_SME = 147;
	public static final int ARM64_GRP_SMEF64 = 148;
	public static final int ARM64_GRP_SMEI64 = 149;
	public static final int ARM64_GRP_MatMulFP32 = 150;
	public static final int ARM64_GRP_MatMulFP64 = 151;
	public static final int ARM64_GRP_MatMulInt8 = 152;
	public static final int ARM64_GRP_V8_1A = 153;
	public static final int ARM64_GRP_V8_3A = 154;
	public static final int ARM64_GRP_V8_4A = 155;
	public static final int ARM64_GRP_ENDING = 156;
}